#
# spec file for package golangci-lint
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           golangci-lint
Version:        1.62.2
Release:        1.1
Summary:        A fast Go linters runner
License:        GPL-3.0-only
URL:            https://golangci-lint.run
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
BuildRequires:  golang(API) >= 1.21

%description
golangci-lint is a fast Go linters runner. It runs linters in parallel, uses
caching, supports yaml config, has integrations with all major IDE and has
dozens of linters included.

%prep
%autosetup -a 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build ./cmd/%{name}

%check
# execute the binary as a basic check
./%{name} --help

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Mon Nov 25 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.62.2:
  * dev: fix release workflow (#5156)
* Mon Nov 25 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.62.1:
  * build(deps): bump github.com/uudashr/iface from 1.2.0 to 1.2.1 (#5154)
  * dev: publish snap (#5130)
  * build(deps): bump github.com/stretchr/testify from 1.9.0 to 1.10.0 (#5152)
  * build(deps): bump github.com/Crocmagnon/fatcontext from 0.5.2 to 0.5.3 (#5153)
  * dev: add missing AUR_KEY secret (#5151)
  * dev: simplify sort results processors (#5150)
  * docs: Simplify team and contributors section (#5148)
  * dev: publish AUR -bin automatically (#5146)
  * build(deps): bump cross-spawn from 6.0.5 to 6.0.6 in /.github/contributors (#5145)
  * docs: remove golint on 'performance' page (#5139)
  * docs: fix URL for revive.ignore-generated-header (#5140)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.6.0 to 1.7.0 (#5134)
  * build(deps): bump cross-spawn from 7.0.3 to 7.0.5 in /.github/peril (#5136)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.18.0 to 0.18.3 (#5133)
  * build(deps): bump github.com/mgechev/revive from 1.5.0 to 1.5.1 (#5135)
  * build(deps): bump github.com/Antonboom/testifylint from 1.5.0 to 1.5.2 (#5132)
  * docs: improve testifylint description of require-f-funcs flag (#5131)
  * fix: ignore cache error when file not found (#5129)
  * build(deps): bump golang.org/x/oauth2 from 0.23.0 to 0.24.0 in /scripts/gen_github_action_config (#5128)
  * docs: missing doc link for sloglint.args-on-sep-lines (#5126)
  * docs: fix links to gocritic checks (#5125)
  * docs: update documentation (#5124)
  * docs: update documentation assets (#5122)
  * docs: update GitHub Action assets (#5123)
* Sun Nov 10 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.62.0:
  * build(deps): bump go-simpler.org/musttag from 0.12.2 to 0.13.0 (#5121)
  * build(deps): bump github.com/lasiar/canonicalheader from 1.1.1 to 1.1.2 (#5119)
  * build(deps): bump golang.org/x/tools from 0.26.0 to 0.27.0 (#5120)
  * build(deps): bump golang.org/x/sys from 0.26.0 to 0.27.0 (#5118)
  * docs: improve forbidigo pattern examples for built-in functions (#5116)
  * fix: Go version propagation (#5109)
  * feat: deprecation step 2 of execinquery and gomnd (#5110)
  * build(deps): bump github.com/mgechev/revive from 1.4.0 to 1.5.0 (#5113)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.17.0 to 0.18.0 (#5114)
  * fix: improve Go detection (#5112)
  * dev: use secure links (#5106)
  * docs: replace staticcheck.io with staticcheck.dev (#5107)
  * docs: fix iface linter name (#5104)
  * dev: extends usage of new Stopwatch methods (#5102)
  * dev: improve readability and maintenance of `internal/cache` (#5101)
  * dev: isolates the code borrowed from Go (#5100)
  * dev: updates internal code borrowed from Go (#5098)
  * build(deps): bump the all group across 3 directories with 5 updates (#5099)
  * build(deps): bump github.com/timonwong/loggercheck from 0.9.4 to 0.10.1 (#5094)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.16.2 to 0.17.0 (#5093)
  * build(deps): bump github.com/sivchari/tenv from 1.10.0 to 1.12.1 (#5090)
  * build(deps): bump github.com/fatih/color from 1.17.0 to 1.18.0 (#5088)
  * Revert "Add filen linter (#5081)" (#5087)
  * code-climate: add check_name field (#5086)
  * dev: remove unused function SetAnalyzerGoVersion (#5085)
  * Add filen linter (#5081)
  * docs: update demo animation (#5083)
  * Add iface linter (#4871)
  * build(deps): bump github.com/golangci/go-printf-func-name from 7558a9eaa5af to v0.1.0 (#5079)
  * build(deps): bump github.com/kisielk/errcheck from 1.7.0 to 1.8.0 (#5074)
  * build(deps): bump github.com/alexkohler/nakedret/v2 from 2.0.4 to 2.0.5 (#5076)
  * build(deps): bump github.com/breml/bidichk from 0.3.1 to 0.3.2 (#5075)
  * build(deps): bump github.com/bkielbasa/cyclop from 1.2.1 to 1.2.3 (#5071)
  * docs: improve new linter section (#5066)
  * build(deps): bump github.com/Abirdcfly/dupword from 0.1.1 to 0.1.3 (#5062)
  * build(deps): bump github.com/go-critic/go-critic from 0.11.4 to 0.11.5 (#5061)
  * build(deps): bump golangci/golangci-lint-action from 6.1.0 to 6.1.1 in the all group (#5059)
  * build(deps): bump github.com/Antonboom/nilnil from 0.1.9 to 1.0.0 (#5058)
  * build(deps): bump github.com/Antonboom/errname from 0.1.13 to 1.0.0 (#5057)
  * build(deps): bump golang.org/x/tools from 0.25.0 to 0.26.0 (#5056)
  * chore: update test workflow
  * build(deps): bump github.com/Antonboom/testifylint from 1.4.3 to 1.5.0 (#5054)
  * fix: type sizing when cross-compiling (32-bit) (#5053)
  * docs: improve 'install from sources' section (#5050)
  * build(deps): bump the all group across 3 directories with 4 updates /testdata (#5049)
  * docs: reorganize configuration files (#5048)
  * dev: remove Nancy (#5047)
  * docs: adds a section about `exclude-dirs-use-default` (#5045)
  * docs: improve FAQ about Go versions (#5046)
  * build(deps): bump go.uber.org/automaxprocs from 1.5.3 to 1.6.0 (#5041)
  * build(deps): bump github.com/alecthomas/go-check-sumtype from 0.1.4 to 0.2.0 (#5038)
  * build(deps): bump github.com/go-viper/mapstructure/v2 from 2.2.0 to 2.2.1 (#5040)
  * build(deps): bump github.com/securego/gosec/v2 from 2.21.3 to 2.21.4 (#5039)
  * docs: improve linter/rule/check docs (#5036)
  * build(deps): bump github.com/mgechev/revive from 1.3.9 to 1.4.0 (#5035)
  * build(deps): bump github.com/go-viper/mapstructure/v2 from 2.1.0 to 2.2.0 (#5034)
  * build(deps): bump github.com/securego/gosec/v2 from 2.21.2 to 2.21.3 (#5029)
  * build(deps): bump github.com/breml/errchkjson from 0.3.6 to 0.4.0 (#5028)
  * build(deps): bump github.com/sonatard/noctx from 0.0.2 to 0.1.0 (#5027)
  * build(deps): bump github.com/ckaznocha/intrange from 0.2.0 to 0.2.1 (#5024)
  * build(deps): bump github.com/breml/bidichk from 0.2.7 to 0.3.1 (#5025)
  * build(deps): bump github.com/ghostiam/protogetter from 0.3.6 to 0.3.8 (#5026)
  * docs: consistent WithSince versions (#5022)
  * build(deps): bump webpack from 5.76.1 to 5.94.0 in /docs (#4968)
  * docs: fix broken link (#5016)
  * build(deps): bump body-parser and express in /docs (#5017)
  * Add recvcheck linter (#5014)
  * dev: use slices package from stdlib (#5011)
  * docs: fix typo in goheader linter desc (#5009)
  * docs: restore JSONschema for v1.60
  * build(deps): bump github.com/tetafro/godot from 1.4.17 to 1.4.18 (#5002)
  * build(deps): bump golang.org/x/tools from 0.24.0 to 0.25.0 (#5001)
  * docs: update documentation (#5000)
  * docs: update documentation assets (#4998)
  * docs: update GitHub Action assets (#4999)
* Thu Nov  7 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.61.0:
  * build(deps): bump github.com/securego/gosec/v2 from 2.21.1 to 2.21.2 (#4997)
  * build(deps): bump github.com/ckaznocha/intrange from 0.1.2 to 0.2.0 (#4996)
  * build(deps): bump github.com/tetafro/godot from 1.4.16 to 1.4.17 (#4993)
  * build(deps): bump github.com/ryancurrah/gomodguard from 1.3.3 to 1.3.5 (#4992)
  * dev: fix nancy
  * docs: add additionnal info about typecheck (#4985)
  * gosec: disable G407 (#4983)
  * build(deps): bump github.com/securego/gosec/v2 from 2.21.0 to 2.21.1 (#4982)
  * build(deps): bump github.com/Crocmagnon/fatcontext from 0.4.0 to 0.5.2 (#4971)
  * build(deps): bump github.com/Abirdcfly/dupword from 0.0.14 to 0.1.1 (#4954)
  * feat: exclude Swagger Codegen files (#4967)
  * feat: add junit-xml-extended format (#4918)
  * build(deps): bump github.com/go-viper/mapstructure/v2 from 2.0.0 to 2.1.0 (#4910)
  * build(deps): bump github.com/securego/gosec/v2 from 2.20.1-0.20240826145712-bcec04e78483 to 2.21.0 (#4981)
  * build(deps): bump peter-evans/create-pull-request from 6 to 7 in the all group (#4978)
  * build(deps): bump the all group across 4 directories with 8 updates (#4979)
  * build(deps): bump golang.org/x/oauth2 from 0.22.0 to 0.23.0 in /scripts/gen_github_action_config in the all group (#4977)
  * chore: improve dependabot configuration
  * nolintlint: remove empty line in unused directive replacement (#4973)
  * build(deps): bump github.com/daixiang0/gci from 0.13.4 to 0.13.5 (#4975)
  * fix: improve runtime version parsing (#4961)
  * build(deps): bump github.com/securego/gosec/v2 from ab3f6c1c83a0 to bcec04e78483 (#4960)
  * build(deps): bump github.com/pelletier/go-toml/v2 from 2.2.2 to 2.2.3 (#4955)
  * build(deps): bump micromatch from 4.0.5 to 4.0.8 in /docs (#4952)
  * build(deps): bump micromatch from 4.0.5 to 4.0.8 in /.github/peril (#4951)
  * build(deps): bump github.com/quasilyte/go-ruleguard to 0fe6f58b47b1 (#4949)
  * docs: update documentation (#4945)
  * docs: update GitHub Action assets (#4944)
* Sat Aug 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.60.3:
  * build(deps): bump github.com/securego/gosec/v2 from 81cda2f91fbe to ab3f6c1c83a0 (#4943)
  * feat: check that Go version use to build is greater or equals to the Go version of the project (#4938)
  * docs: update documentation (#4931)
  * docs: update documentation assets (#4930)
  * docs: update GitHub Action assets (#4929)
* Wed Aug 21 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.60.2:
  * build(deps): bump github.com/securego/gosec/v2 from 5f0084eb01a9 to 81cda2f91fbe (#4927)
  * dev: fix GO_VERSION in post release workflow (#4926)
  * exportloopref: deprecation (#4916)
  * chore: update gofmt (#4923)
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.8.3 to 2.9.0 (#4921)
  * build(deps): bump mvdan.cc/gofumpt from 0.6.0 to 0.7.0 (#4922)
  * staticcheck: propagate Go version (#4907)
  * gosec: add G602 analyzer (#4906)
  * build(deps): bump honnef.co/go/tools from 0.5.0 to 0.5.1 (#4911)
  * docs: update documentation (#4903)
  * docs: update documentation assets (#4901)
  * docs: update GitHub Action assets (#4902)
* Wed Aug 14 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.60.1:
  * chore: free skip space during release
* Wed Aug 14 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.60.0:
  * go1.23 support (#4836)
  * build(deps): bump golang.org/x/tools from 0.23.0 to 0.24.0 (#4898)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.5.2 to 1.6.0 (#4899)
  * unused: remove exported-is-used option
  * build(deps): bump golangci/golangci-lint-action from 6.0.1 to 6.1.0 (#4893)
  * build(deps): bump golang.org/x/oauth2 from 0.21.0 to 0.22.0 in /scripts/gen_github_action_config (#4892)
  * unused: remove exported-is-used option (#4890)
  * build(deps): bump github.com/mgechev/revive from 1.3.7 to 1.3.9 (#4886)
  * build(deps): bump github.com/gofrs/flock from 0.12.0 to 0.12.1 (#4889)
  * build(deps): bump github.com/uudashr/gocognit from 1.1.2 to 1.1.3 (#4887)
  * build(deps): bump github.com/Crocmagnon/fatcontext from 0.3.0 to 0.4.0 (#4888)
  * dev: add comment to clarify using empty issues slice (#4884)
  * feat: improve processors filtering stats (#4882)
  * docs: improve ireturn documentation (#4881)
  * fix: typecheck issues should never be ignored (#4870)
  * chore: fix checklist
  * build(deps): bump golang.org/x/tools from 0.22.0 to 0.23.0 (#4868)
  * build(deps): bump github.com/gofrs/flock from 0.10.0 to 0.12.0 (#4863)
  * build(deps): bump github.com/valyala/quicktemplate from 1.7.0 to 1.8.0 (#4862)
  * dev: fix code QL warning
  * docs: improve grammar of new linter checklist (#4861)
  * chore: change .yaml to .yml for consistency (#4860)
  * dev: add action to add checklist for new linter (#4855)
  * docs: remove 'trusted by' page (#4857)
  * docs: add link on linter without configuration (#4843)
  * build(deps): bump github.com/ryancurrah/gomodguard from 1.3.2 to 1.3.3 (#4851)
  * build(deps): bump github.com/gofrs/flock from 0.8.1 to 0.10.0 (#4852)
  * build(deps): bump github.com/moricho/tparallel from 0.3.1 to 0.3.2 (#4849)
  * dev: rewrite benchmarks (#4848)
  * dev: clean gen_github_action_config (#4847)
  * docs: update wsl documentation (#4846)
  * chore: update package-lock.json
  * build(deps): bump github.com/bombsimon/wsl/v4 from 4.4.0 to 4.4.1 (#4844)
  * build(deps): bump github.com/Antonboom/testifylint from 1.4.2 to 1.4.3 (#4839)
  * build(deps): bump go-simpler.org/sloglint from 0.7.1 to 0.7.2 (#4840)
  * docs: add repology package summary (#4838)
  * dev: improve benchmark scripts (#4826)
  * build(deps): bump github.com/jjti/go-spancheck from 0.6.1 to 0.6.2 (#4833)
  * fix: sanitize level property for SARIF (#4831)
  * build(deps): bump github.com/spf13/cobra from 1.7.0 to 1.8.1 (#4822)
  * build(deps): bump github.com/sivchari/tenv from 1.9.1 to 1.10.0 (#4823)
  * build(deps): bump github.com/Antonboom/testifylint from 1.4.1 to 1.4.2 (#4821)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.26.0 to 1.27.0 (#4820)
  * dev: improve revive construction (#4817)
  * dev: fix installation script for curl v8.8.0 (#4814)
  * docs: move whole-files near of new-from-xxx (#4815)
  * build(deps): bump braces from 3.0.2 to 3.0.3 in /docs (#4812)
  * build(deps): bump braces from 3.0.2 to 3.0.3 in /.github/peril (#4811)
  * build(deps): bump golang.org/x/oauth2 from 0.20.0 to 0.21.0 in /scripts/gen_github_action_config (#4810)
  * build(deps): bump goreleaser/goreleaser-action from 5 to 6 (#4809)
  * build(deps): bump github.com/sivchari/tenv from 1.7.1 to 1.9.1 (#4808)
  * build(deps): bump github.com/bombsimon/wsl/v4 from 4.3.0 to 4.4.0 (#4807)
  * build(deps): bump github.com/Antonboom/testifylint from 1.3.1 to 1.4.1 (#4798)
  * build(deps): bump github.com/Crocmagnon/fatcontext from 0.2.2 to 0.3.0 (#4783)
  * lll: Advertise max line length instead of just reporting failure (#4781)
  * build(deps): bump github.com/GaijinEntertainment/go-exhaustruct/v3 from 3.2.0 to 3.3.0 (#4760)
  * build(deps): bump github.com/bombsimon/wsl/v4 from 4.2.1 to 4.3.0 (#4799)
  * docs: update documentation assets (#4806)
  * docs: update GitHub Action assets (#4805)
* Sun Jun  9 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.59.1:
  * build(deps): bump github.com/golangci/misspell from 0.5.1 to 0.6.0 (#4804)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.25.0 to 1.26.0 (#4801)
  * build(deps): bump golang.org/x/tools from 0.21.0 to 0.22.0 (#4802)
  * intrange: add style preset (#4797)
  * docs: update revive configuration (#4790)
  * chore: improve issue templates
  * chore: improve issue templates
  * dev: improve issue templates
  * build(deps): bump github.com/go-viper/mapstructure/v2 from 2.0.0-alpha.1 to 2.0.0 (#4788)
  * unparam: bump to HEAD (#4786)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.5.1 to 1.5.2 (#4785)
  * build(deps): bump go-simpler.org/sloglint from 0.7.0 to 0.7.1 (#4784)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.24.4 to 3.24.5 (#4782)
  * chore: fix bench scripts
  * chore: update badges
  * dev: remove unused field from PathPrettifier (#4778)
  * fix: SARIF format require issue column >= 1 (#4775)
  * dev: display version in verbose mode (#4771)
  * fix: gomnd deprecated configuration compatibility (#4768)
  * dev: add targets to benchmark a linter (#4761)
  * docs: fix broken link (#4766)
  * docs: fix typos (#4763)
  * build(deps): bump github.com/Antonboom/testifylint from 1.3.0 to 1.3.1 (#4759)
  * fix: init empty result slice for SARIF printer (#4758)
  * dev: fix double call to startTracing (#4757)
  * docs: update documentation (#4756)
  * docs: update documentation assets (#4749)
  * docs: update GitHub Action assets (#4750)
* Sun May 26 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.59.0:
  * build(deps): bump github.com/securego/gosec/v2 from 2.20.0 to 5f0084eb01a9 (#4748)
  * dev: fix badges
  * dev: improve issue chooser (#4747)
  * build(deps): bump github.com/BurntSushi/toml from 1.3.2 to 1.4.0 (#4746)
  * build(deps): bump github.com/hashicorp/go-version from 1.6.0 to 1.7.0 (#4745)
  * chore: use global security policy
  * feat: allow the analysis of generated files (#4740)
  * feat: add warning about disabled and deprecated linters (level 2) (#4742)
  * chore: add html to the JSONSchema  (#4737)
  * build(deps): bump github.com/go-critic/go-critic from 0.11.3 to 0.11.4 (#4738)
  * chore: improve grammar in the security policy (#4739)
  * chore: add security policy
  * fix: remove errcheck defaults (#4734)
  * docs: update documentation (#4732)
  * feat: deprecate github-actions format (#4726)
  * Support Sarif output (#4723)
  * build(deps): bump github.com/Antonboom/testifylint from 1.2.0 to 1.3.0 (#4729)
  * build(deps): bump go-simpler.org/sloglint from 0.6.0 to 0.7.0 (#4718)
  * docs: update GitHub Action assets (#4731)
* Sun May 19 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.58.2:
  * build(deps): bump github.com/securego/gosec/v2 from 2.19.0 to 2.20.0 (#4724)
  * build(deps): bump github.com/fatih/color from 1.16.0 to 1.17.0 (#4725)
  * build(deps): bump golangci/golangci-lint-action from 5.3.0 to 6.0.1 (#4722)
  * docs: improve integrations and install pages (#4719)
  * docs: uses org account for GitHub Sponsor
  * docs: funding and social networks
  * docs: funding and social networks
  * build(deps): bump github.com/Antonboom/nilnil from 0.1.8 to 0.1.9 (#4716)
  * build(deps): bump github.com/lasiar/canonicalheader from 1.0.6 to 1.1.1 (#4715)
  * dev: set CGO_ENABLED=1 when running "test" task (#4712)
  * build(deps): bump go-simpler.org/musttag from 0.12.1 to 0.12.2 (#4710)
  * docs: update documentation (#4711)
  * dev: deprecate errcheck.ignore option (#4709)
  * docs: update GitHub Action assets (#4708)
* Wed May  8 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.58.1:
  * build(deps): bump github.com/4meepo/tagalign from 1.3.3 to 1.3.4 (#4705)
  * build(deps): bump github.com/ghostiam/protogetter from 0.3.5 to 0.3.6 (#4707)
  * build(deps): bump golang.org/x/tools from 0.20.0 to 0.21.0 (#4706)
  * fix: remove GitHub Action problem matchers (#4700)
  * build(deps): bump golangci/golangci-lint-action from 5.1.0 to 5.3.0 (#4701)
  * build(deps): bump golang.org/x/oauth2 from 0.19.0 to 0.20.0 in /scripts/gen_github_action_config (#4702)
  * fix: gochecknoinits shadow name (#4698)
  * chore: keep v1.57 JSON schema
  * docs: update documentation (#4694)
  * docs: update documentation assets (#4692)
  * docs: update GitHub Action assets (#4693)
* Fri May  3 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.58.0:
  * feat: use problem matchers for GitHub Action format (#4685)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.4.8 to 1.5.1 (#4690)
  * unparam: bump to HEAD (#4689)
  * build(deps): bump github.com/pelletier/go-toml/v2 from 2.2.1 to 2.2.2 (#4688)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.24.3 to 3.24.4 (#4686)
  * build(deps): bump golangci/golangci-lint-action from 4.0.0 to 5.1.0 (#4684)
  * feat: log an error when using previously deprecated linters (#4681)
  * build(deps): bump github.com/lasiar/canonicalheader from 1.0.5 to 1.0.6 (#4682)
  * dev: clean deprecated options (#4673)
  * dev: removes BaseRule, ExcludeRule, SeverityRule duplications (#4676)
  * Add new linter canonicalheader (#4672)
  * build(deps): bump github.com/jjti/go-spancheck from 0.6.0 to 0.6.1 (#4679)
  * fix: don't hide typecheck errors inside diff processor (#4674)
  * dev: dedicated package about  IllTypedError parsing (#4675)
  * build(deps): bump github.com/yeya24/promlinter from 0.2.0 to 0.3.0 (#4671)
  * build(deps): bump github.com/jjti/go-spancheck from 0.5.3 to 0.6.0 (#4670)
  * build(deps): bump github.com/Antonboom/errname from 0.1.12 to 0.1.13 (#4669)
  * build(deps): bump github.com/Antonboom/nilnil from 0.1.7 to 0.1.8 (#4668)
  * build(deps): bump gitlab.com/bosi/decorder from 0.4.1 to 0.4.2 (#4667)
  * fix: skip go.mod report inside autogenerated_exclude processor (#4663)
  * build(deps): bump github.com/firefart/nonamedreturns from 1.0.4 to 1.0.5 (#4666)
  * build(deps): bump github.com/golangci/misspell from 0.4.1 to 0.5.1 (#4665)
  * build(deps): bump github.com/ultraware/whitespace from 0.1.0 to 0.1.1 (#4664)
  * build(deps): bump go-simpler.org/sloglint from 0.5.1 to 0.6.0 (#4645)
  * fix: speed up "fast" linters (#4653)
  * dev: improve goreleaser configuration (#4660)
  * dev: fix shellcheck lint issues (#4657)
  * fix: use plugin version (#4655)
  * dev: fix broken links to the website (#4656)
  * execinquery: deprecation (#4652)
  * dev: replace fmt.Errorf by errors.New (#4647)
  * dev: eliminate redundant indentation (#4650)
  * dev: close errcheck exclude file (#4649)
  * dev: close file
  * fix: keep only typecheck issues (#4640)
  * build(deps): bump go-simpler.org/sloglint from 0.5.0 to 0.5.1 (#4644)
  * build(deps): bump github.com/pelletier/go-toml/v2 from 2.2.0 to 2.2.1 (#4643)
  * dev: sorts deprecated linters at the end of lists (#4642)
  * dev: remove alternatives names from CLI help (#4641)
  * dev: clean DefaultExcludePatterns and improve CLI render (#4638)
  * dev: improve formatting and description in flagsets (#4636)
  * docs: use proper templates when creating GitHub issues (#4637)
  * dev: group skip-dir related elements (#4631)
  * build(deps): bump github.com/golangci/revgrep from 0.5.2 to 0.5.3 (#4633)
  * build(deps): bump github.com/karamaru-alpha/copyloopvar from 1.0.10 to 1.1.0 (#4632)
  * dev: group linter implementation and integration tests (#4603)
  * docs: remove deprecated Atom from Editor Integrations (#4628)
  * build(deps): bump go-simpler.org/musttag from 0.12.0 to 0.12.1 (#4626)
  * build(deps): bump peaceiris/actions-gh-pages from 3 to 4 (#4625)
  * build(deps): bump golang.org/x/oauth2 from 0.18.0 to 0.19.0 in /scripts/gen_github_action_config (#4624)
  * chore: add chocolatey (#4615)
  * build(deps): bump golang.org/x/tools from 0.19.0 to 0.20.0 (#4620)
  * build(deps): bump github.com/go-critic/go-critic from 0.11.2 to 0.11.3 (#4619)
  * build(deps): bump go-simpler.org/musttag from 0.11.0 to 0.12.0 (#4621)
  * fix: JSON schema about severities (#4617)
  * build(deps): bump github.com/ryancurrah/gomodguard from 1.3.1 to 1.3.2 (#4614)
  * build(deps): bump github.com/leonklingele/grouper from 1.1.1 to 1.1.2 (#4613)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.24.2 to 3.24.3 (#4612)
  * build(deps): bump github.com/daixiang0/gci from 0.13.3 to 0.13.4 (#4611)
  * build(deps): bump github.com/butuzov/mirror from 1.1.0 to 1.2.0 (#4610)
  * docs: fix links to Module and Go Plugins (#4607)
  * dev: set timeout for loading JSON schema (#4605)
  * dev: option to not check deprecation (#4591)
  * feat: add fatcontext linter (#4583)
  * Add `pre-commit` hook to run `config verify` (#4602)
  * build(deps): bump github.com/ckaznocha/intrange from 0.1.1 to 0.1.2 (#4601)
  * build(deps): bump go-simpler.org/musttag from 0.10.0 to 0.11.0 (#4600)
  * dev: clean up unused receivers with revive (#4599)
  * dev: add fix test for mirror linter (#4598)
  * fix: remove help display on error with verify command (#4597)
  * dev: unifying processors code style (#4592)
  * dev: enable testifylint linter (#4595)
  * dev: add fix test for tagalign linter (#4594)
  * docs: update documentation (#4590)
  * feat: replace gomnd by mnd (#4572)
  * feat: err113 analyzer name (#4567)
  * dev: add test for grouper linter (#4585)
  * build(deps): bump go-simpler.org/musttag from 0.9.0 to 0.10.0 (#4579)
  * feat: deprecate usage of linter alternative names (#4562)
  * build(deps): bump github.com/daixiang0/gci from 0.12.3 to 0.13.3 (#4522)
  * dev: clean code arround CLI args usage (#4557)
  * docs: update documentation assets (#4588)
  * docs: update GitHub Action assets (#4589)
* Thu Mar 28 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.57.2:
  * fix: hide useless warning (#4587)
  * build(deps): bump github.com/karamaru-alpha/copyloopvar from 1.0.9 to 1.0.10 (#4584)
  * build(deps): bump express from 4.18.2 to 4.19.2 in /docs (#4581)
  * build(deps): bump github.com/ldez/gomoddirectives from 0.2.3 to 0.2.4 (#4580)
  * dev: organize golinters package (#4578)
  * dev: minor clean up (#4577)
  * dev: remove unused markdownlint config file (#4576)
  * fix: missing output format (#4574)
  * fix: the TeamCity inspectionType service message (#4573)
  * fix: display warnings on deprecated linter options (#4568)
  * docs: improve linters page (#4571)
  * build(deps): bump github.com/ckaznocha/intrange from 0.1.0 to 0.1.1 (#4570)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.16.1 to 0.16.2 (#4569)
  * docs: remove invalid example about mixing files and directory (#4566)
  * build(deps): bump github.com/kkHAIKE/contextcheck from 1.1.4 to 1.1.5 (#4564)
  * build(deps): bump github.com/karamaru-alpha/copyloopvar from 1.0.8 to 1.0.9 (#4565)
  * dev: improve feature request issue form (#4560)
  * build(deps): bump github.com/jgautheron/goconst from 1.7.0 to 1.7.1 (#4555)
  * docs: update GitHub Action assets (#4553)
* Thu Mar 21 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.57.1:
  * fix: filter invalid issues before other processors (#4552)
  * build(deps): bump github.com/pelletier/go-toml/v2 from 2.1.1 to 2.2.0 (#4548)
  * build(deps): bump github.com/golangci/plugin-module-register from 0.1.0 to 0.1.1 (#4549)
  * dev: improve dependabot configuration
  * docs: fix default value for sloglint no-global (#4547)
  * docs: update documentation (#4546)
  * docs: update documentation assets (#4545)
  * docs: update GitHub Action assets
* Wed Mar 20 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Re-enable binary stripping and debuginfo boo#1210938
  * Use BuildRequires: golang(API) >= 1.21 instead of go.
    The go metapackage points to a single go version that
    increments at a date TBD after each go1.x major release. The
    expression golang(API) is available immediately upon each go1.x
    major release and is stable for expressing the minimum version
    or a temporarily pinned version.
  * Use BuildRequires: golang(API) >= 1.21 matching go.mod
  * Drop BuildRequires: go-md2man and use plain markdown as %%doc
  * Use autosetup -a 1 to unpack source and vendored dependencies
  * Drop mod=vendor, go1.14+ will detect vendor dir and auto-enable
  * Build PIE with pattern that may become recommended procedure:
    %%%%ifnarch ppc64 GOFLAGS="-buildmode=pie" %%%%endif go build
    A go toolchain buildmode default config would be preferable
    but none exist at this time.
  * Remove ldflags -s (Omit symbol table and debug info) and -w
    (Omit DWARF symbol table). This information is used to produce
    separate debuginfo packages and binaries are stripped for
    reduced size by GNU strip during RPM build.
  * Remove ldflags -X entries for build time stamp.
    This information is embedded in binaries with go1.18+ and
    available via go version -m or runtime/debug.ReadBuildInfo().
  * Drop go build -o arg, default binary name is pkg of main()
  * Add basic %%check to execute binary --help
  * Use %%license dropping conditional for 0%%{?suse_version} < 1500.
    %%license macro is available since rpm-4.11+, SLE-12:SP3+
* Wed Mar 20 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.57.0:
  * fix: disable temporarily httpresponse from govet (#4528)
  * dev: silence help on some commands usage on error (#4542)
  * feat: add verify command (#4527)
  * dev: refactor .golangci.yml configuration and fix up nolintlint issues (#4537)
  * build(deps): bump github.com/alexkohler/nakedret/v2 from 2.0.2 to 2.0.4 (#4540)
  * build(deps): bump github.com/ghostiam/protogetter from 0.3.4 to 0.3.5 (#4539)
  * build(deps): bump github.com/ryancurrah/gomodguard from 1.3.0 to 1.3.1 (#4538)
  * dev: fix exclude-rules text
  * govet: add a warning about the deprecation of check-shadowing (#4535)
  * feat: improve 'no go files to analyze' message (#4536)
  * govet: fix check-shadowing (#4534)
  * Revert "fix: deprecation message related to UseDefaultSkipDirs (#4533)"
  * fix: deprecation message related to UseDefaultSkipDirs (#4533)
  * fix: use GOTOOLCHAIN=auto inside the Docker images (#4532)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.16.0 to 0.16.1 (#4531)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.15.2 to 0.16.0 (#4530)
  * feat: new output.formats file configuration syntax (#4521)
  * dev: run all commands on the CI (#4526)
  * dev: validate test configurations (#4520)
  * dev: remove Run.Args (#4525)
  * feat: create output directory (#4524)
  * dev: split ContextLoader (#4516)
  * build(deps): bump go-simpler.org/sloglint from 0.4.0 to 0.5.0 (#4523)
  * docs: add more tagliatelle examples (#4519)
  * feat: replace `run.skip-xxx` options by `issues.exclude-xxx` options (#4509)
  * docs: fix website broken links (#4518)
  * dev: review config path usage inside gocritic (#4517)
  * feat: rename exclude-autogenerated-strict to exclude-generated-strict (#4514)
  * docs: fix installation link in the readme (#4515)
  * build(deps): bump follow-redirects from 1.15.4 to 1.15.6 in /docs (#4513)
  * build(deps): bump github.com/golangci/plugin-module-register to 0.1.0 (#4510)
  * feat: option to strictly follow Go autogenerated file convention (#4507)
  * docs: organize sections and pages (#4493)
  * docs: fix plugin example URL (#4508)
  * dev: clean up (#4502)
  * docs: shorten description for gochecknoglobals linter (#4505)
  * build(deps): bump google.golang.org/protobuf from 1.31.0 to 1.33.0 (#4503)
  * dev: reformat code with gofumpt (#4500)
  * chore: simplify comparators (#4499)
  * dev: clean up (#4495)
  * docs: improve "about golangci-lint" in README (#4498)
  * dev: display help message with green color (#4497)
  * docs: fix linters page
  * docs: improve plugins page (#4494)
  * dev: use `cmd.Context` inside custom command (#4496)
  * docs: fix JSON schema publishing
  * docs: publish JSON schema on golangci-lint.run (#4488)
  * dev: minor clean up (#4492)
  * dev: fix a typo in the log about preserving temp (#4491)
  * docs: improve grammar in the custom linter article (#4489)
  * docs: add jsonschema (#4487)
  * dev: improve version output (#4483)
  * docs: use information from the previous release to create pages (#4457)
  * build(deps): downgrade github.com/daixiang0/gci from 0.13.0 to 0.12.3 (#4484)
  * feat: syntax to not override severity from linters (#4472)
  * docs: define linter deprecation cycle (#4474)
  * feat: new custom linters system (#4437)
  * dev: the printer just needs Output configuration (#4479)
  * dev: clean up command contructors (#4478)
  * dev: clean context loader (#4480)
  * dev: remove unused release target (#4481)
  * fix: panic when concurrency=0 (#4477)
  * fix: rule severity is required (#4469)
  * fix: store and read severity from linters in the cache (#4468)
  * feat: use gosec severities (#4470)
  * build(deps): bump github.com/golangci/unconvert to HEAD (#4473)
  * feat: add sort-order option (#4467)
  * docs: add explanation about the configuration inside repo  (#4466)
  * fix: use first issue without inline on mergeLineIssues on multiplie issues (#3316)
  * dev: add GL_DEBUG=govet to see enabled analyzers (#4465)
  * build(deps): bump golang.org/x/oauth2 from 0.17.0 to 0.18.0 in /scripts/gen_github_action_config (#4464)
  * feat: allow running only a specific linter without modifying the file configuration (#4438)
  * dev: fix nancy
  * build(deps): bump golang.org/x/tools from 0.18.0 to 0.19.0 (#4462)
  * dev: rename function parameter `i` to `issue` (#4460)
  * docs: fix typo in 'e.g.' (#4461)
  * chore: nancy
  * dev: simplify exclude processors (#4456)
  * docs: don't mark dupword as autofixable (#4455)
  * feat: option to not override severity from linters (#4452)
  * dev: simplify severity processor (#4451)
  * fix: move show-stats field from run to output (#4439)
  * feat: inactivate deprecated linters (#4436)
  * dev: split post-release workflow (#4440)
  * dev: isolate printer code (#4435)
  * feat: automatically adjust the maximum concurrency to the container CPU quota (#4441)
  * build(deps): bump github.com/Antonboom/testifylint from 1.1.3 to 1.2.0 (#4449)
  * dev: adjust replacement msg for nosnakecase (#4443)
  * build(deps): bump github.com/karamaru-alpha/copyloopvar from 1.0.4 to 1.0.8 (#4444)
  * build(deps): bump github.com/stretchr/testify from 1.8.4 to 1.9.0 (#4448)
  * build(deps): bump github.com/Antonboom/testifylint from 1.1.2 to 1.1.3 (#4447)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.24.1 to 3.24.2 (#4446)
  * dev: rewrite linters Manager (#4419)
  * docs: expand install manual for running website locally (#4431)
  * build(deps): bump github.com/daixiang0/gci from 0.12.3 to 0.13.0 (#4429)
  * build(deps): bump github.com/go-critic/go-critic from 0.11.1 to 0.11.2 (#4430)
  * build(deps): bump go-simpler.org/musttag from 0.8.0 to 0.9.0 (#4428)
  * dev: add test on ExcludeRule and SeverityRule (#4420)
  * build(deps): bump es5-ext from 0.10.53 to 0.10.63 in /docs (#4422)
  * dev: new commands system (#4412)
  * dev: clean reference file (#4418)
  * dev: add tests on linterdb package (#4416)
  * build(deps): bump github.com/denis-tingaikin/go-headerfrom 0.4.3 to 0.5.0 (#4396)
  * build(deps): bump github.com/jjti/go-spancheck from 0.5.2 to 0.5.3 (#4414)
  * dev: clean up Executor  (#4404)
  * build(deps): bump honnef.co/go/tools from 0.4.6 to 0.4.7 (#4410)
  * docs: update code snippets in Architecture (#4409)
  * install.sh: set executable bit for Unix (#4408)
  * dev: install.sh remove obsolete reference to godownloader (#4407)
  * dev: install.sh fix usage message (#4406)
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.8.1 to 2.8.3 (#4403)
  * build(deps): bump github.com/catenacyber/perfsprint from 0.7.0 to 0.7.1 (#4402)
  * misspell: add extra-words (#4401)
  * feat: disable copyloopvar and intrange on Go < 1.22 (#4397)
  * gocritic: support of enable-all and disable-all options (#4335)
  * build(deps): bump github.com/daixiang0/gci from 0.12.1 to 0.12.3 (#4400)
  * build(deps): bump github.com/Abirdcfly/dupword from 0.0.13 to 0.0.14 (#4398)
  * build(deps): bump github.com/kunwardeep/paralleltest from 1.0.9 to 1.0.10 (#4394)
  * feat: add copyloopvar linter (#4382)
  * feat: add intrange linter (#4378)
  * dev: fix Docker image on tag (#4392)
  * docs: improve `govet` description (#4366)
  * build(deps): bump github.com/catenacyber/perfsprint from 0.6.0 to 0.7.0 (#4386)
  * revive: add exclude option (#4365)
  * docs: Update documentation and assets
* Thu Feb 15 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.56.2:
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.24.0 to 1.25.0 (#4390)
  * build(deps): bump github.com/securego/gosec/v2 from 2.18.2 to 2.19.0 (#4389)
  * build(deps): bump github.com/go-critic/go-critic from 0.11.0 to 0.11.1 (#4388)
  * build(deps): bump golang.org/x/tools from 0.17.0 to 0.18.0 (#4387)
  * build(deps): bump golang.org/x/oauth2 from 0.16.0 to 0.17.0 in /scripts/gen_github_action_config (#4380)
  * build(deps): bump golangci/golangci-lint-action from 3.7.0 to 4.0.0 (#4379)
  * docs: explain limitation of new-from-rev and new-from-patch (#4377)
  * dev: handle old TODO (#4374)
  * dev: fix govet.nilness lint issues (#4373)
  * dev: refactor govet impl with slices.Contains (#4372)
  * build(deps): bump github.com/Antonboom/testifylint from 1.1.1 to 1.1.2 (#4371)
  * dev: use goreleaser to create Docker images (#4370)
  * build(deps): bump github.com/bombsimon/wsl/v4 from 4.2.0 to 4.2.1 (#4367)
  * docs: Update documentation and assets (#4362)
* Thu Feb 15 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.56.1:
  * build(deps): bump github.com/Antonboom/testifylint from 1.1.0 to 1.1.1 (#4359)
  * build(deps): bump github.com/kisielk/errcheck from 1.6.3 to 1.7.0 (#4358)
  * govet: disable loopclosure with go1.22 (#4357)
  * build(deps): bump github.com/mgechev/revive from 1.3.6 to 1.3.7 (#4355)
  * dev: use matrix go version
  * docs: Update documentation and assets (#4354)
* Wed Feb  7 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.56.0:
  * build(deps): bump github.com/GaijinEntertainment/go-exhaustruct/v3 from 3.1.0 to 3.2.0 (#4304)
  * go1.22 support (#4272)
  * build(deps): bump github.com/butuzov/ireturn from 0.2.2 to 0.3.0 (#4352)
  * build(deps): bump peter-evans/create-pull-request from 5 to 6 (#4348)
  * dev: remove unrelated flags from config and linters command (#4284)
  * build(deps): bump github.com/catenacyber/perfsprint from 0.5.0 to 0.6.0 (#4346)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.12 to 3.24.1 (#4344)
  * feat: implement stats per linter with a flag (#4341)
  * docs: adjust list from why install from source is not recommended (#4340)
  * dev: replace mitchellh/mapstructure by go-viper/mapstructure/v2 (#4339)
  * build(deps): bump mvdan.cc/gofumpt from 0.5.0 to 0.6.0 (#4338)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.4.7 to 1.4.8 (#4337)
  * build(deps): bump mvdan.cc/unparam from 20221223090309-7455f1af531d to 20240104100049-c549a3470d14 (#4333)
  * dev: check go.sum is up to date (#4334)
  * build(deps): bump github.com/Antonboom/testifylint from 1.0.2 to 1.1.0 (#4330)
  * build(deps): bump actions/cache from 3 to 4 (#4329)
  * build(deps): bump github.com/ghostiam/protogetter from 0.3.3 to 0.3.4 (#4327)
  * docs: adjust wrapcheck ignoreSigs to new defaults (#4326)
  * devs: fix typo in testdata for gochecknoglobals (#4320)
  * fix: parse Go RC version (#4319)
  * build(deps): bump github.com/alecthomas/go-check-sumtype from 0.1.3 to 0.1.4 (#4317)
  * build(deps): bump github.com/mgechev/revive from 1.3.5 to 1.3.6 (#4314)
  * build(deps): bump golang.org/x/tools from 0.16.1 to 0.17.0 (#4315)
  * build(deps): bump github.com/jjti/go-spancheck from 0.4.2 to 0.5.2 (#4316)
  * build(deps): bump follow-redirects from 1.14.8 to 1.15.4 in /docs (#4309)
  * build(deps): bump golang.org/x/oauth2 from 0.15.0 to 0.16.0 in /scripts/gen_github_action_config (#4308)
  * build(deps): bump github.com/cloudflare/circl from 1.3.3 to 1.3.7 in /tools (#4307)
  * docs: improve typecheck FAQ (#4306)
  * build(deps): bump github.com/mgechev/revive from 1.3.4 to 1.3.5 (#4305)
  * docs: fix grammar (#4302)
  * dev: replace raw loops with funcs from slices and maps (#4299)
  * feat: add `spancheck` linter (#4290)
  * docs: fix noctx description (#4297)
  * build(deps): bump github.com/go-critic/go-critic from 0.10.0 to 0.11.0 (#4295)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.11 to 3.23.12 (#4296)
  * dev: enable errorlint linter (#4292)
  * build(deps): bump github.com/daixiang0/gci from 0.12.0 to 0.12.1 (#4293)
  * dev: replace hashicorp/go-multierror with errors.Join (#4291)
  * build(deps): bump msgpackr from 1.5.4 to 1.10.1 in /docs (#4289)
  * build(deps): bump github.com/go-git/go-git/v5 from 5.4.2 to 5.11.0 in /tools (#4288)
  * doc: add missing fields to .golangci.reference.yml (#4285)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.15.1 to 0.15.2 (#4282)
  * misspell: add mode option (#4275)
  * fix: make versioning inside Docker image consistent with binaries (#4279)
  * doc: fix URL not available (#4280)
  * docs: fix Go version fallback  (#4277)
  * docs: update link (#4274)
  * docs: improve .golangci.reference.yml defaults (#4271)
  * build(deps): bump golang.org/x/crypto from 0.14.0 to 0.17.0 in /tools (#4269)
  * build(deps): bump github/codeql-action from 2 to 3 (#4266)
  * build(deps): github.com/macabu/inamedparam from 0.1.2 to 0.1.3 (#4261)
  * build(deps): bump github.com/daixiang0/gci from 0.11.2 to 0.12.0 (#4260)
  * build(deps): bump go-simpler.org/sloglint from 0.3.0 to 0.4.0 (#4257)
  * build(deps): bump github.com/catenacyber/perfsprint from 0.4.0 to 0.5.0 (#4258)
  * build(deps): bump github.com/kunwardeep/paralleltest from 1.0.8 to 1.0.9 (#4256)
  * build(deps): bump golang.org/x/tools from 0.16.0 to 0.16.1 (#4259)
  * build(deps): bump github.com/sigstore/cosign from 1.13.1 to 1.13.2 in /tools (#4251)
  * build(deps): bump actions/setup-go from 4 to 5 (#4250)
  * build(deps): bump github.com/go-critic/go-critic from 0.9.0 to 0.10.0 (#4249)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.14.1 to 0.15.1 (#4248)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.4.6 to 1.4.7 (#4245)
  * build(deps): bump github.com/catenacyber/perfsprint from 0.3.1 to 0.4.0 (#4236)
  * build(deps): bump github.com/ykadowak/zerologlint from 0.1.4 to 0.1.5 (#4235)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.4.5 to 1.4.6 (#4234)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.10 to 3.23.11 (#4233)
  * build(deps): bump golang.org/x/tools from 0.15.0 to 0.16.0 (#4232)
  * dev: use zerologlint analyzer fields for name and doc (#4225)
  * build(deps): bump github.com/bombsimon/wsl/v4 from 3.4.0 to 4.2.0 (#4215)
  * sloglint: add static-msg option (#4213)
  * build(deps): bump golang.org/x/oauth2 from 0.14.0 to 0.15.0 in /scripts/gen_github_action_config (#4223)
  * dev: replace tab by space inside CLI help (#4221)
  * build(deps): bump github.com/ykadowak/zerologlint from 0.1.3 to 0.1.4 (#4222)
  * dev: use analyzer fields for name, doc instead of hardcoded strings (#4214)
  * chore: build doc on PR
  * build(deps): bump github.com/OpenPeeDeeP/depguard/v2 from 2.1.0 to 2.2.0 (#4207)
  * build(deps): bump golang.org/x/oauth2 from 0.13.0 to 0.14.0 in /scripts/gen_github_action_config (#4203)
  * build(deps): bump go-simpler.org/musttag from v0.7.2 to v0.8.0 (#4201)
  * build(deps): bump github.com/jgautheron/goconst from 1.6.0 to 1.7.0 (#4200)
  * build(deps): bump github.com/catenacyber/perfsprint from 0.3.0 to 0.3.1 (#4199)
  * build(deps): bump github.com/nishanths/exhaustive from 0.11.0 to 0.12.0 (#4195)
  * build(deps): bump github.com/fatih/color from 1.15.0 to 1.16.0 (#4194)
  * build(deps): bump github.com/Antonboom/testifylint from 1.0.1 to 1.0.2 (#4193)
  * build(deps): bump github.com/tetafro/godot from 1.4.15 to 1.4.16 (#4192)
  * build(deps): bump golang.org/x/tools from 0.14.0 to 0.15.0 (#4191)
  * docs: note that `exhaustruct` struct regular expressions are expected to match the entire `package/name/structname` (#4190)
  * build(deps): bump github.com/Antonboom/testifylint from 0.2.3 to 1.0.1 (#4186)
  * build(deps): bump github.com/ghostiam/protogetter from 0.3.1 to 0.3.3 (#4185)
  * build(deps): bump go-simpler.org/sloglint from 0.2.0 to 0.3.0 (#4183)
  * whitespace: update after moving to the `analysis` package (#4003)
  * build(deps): bump github.com/gordonklaus/ineffassign from 0.0.0-20230610083614-0e73809eb601 to 0.1.0 (#4173)
  * build(deps): bump github.com/ghostiam/protogetter from 0.2.3 to 0.3.1 (#4167)
  * build(deps): bump go-simpler.org/sloglint from 0.1.2 to 0.2.0 (#4166)
  * build(deps): bump github.com/catenacyber/perfsprint from 0.2.0 to 0.3.0 (#4157)
  * docs: Update documentation and assets (#4181)
* Fri Nov  3 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.55.2:
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.9 to 3.23.10 (#4177)
  * build(deps): bump github.com/butuzov/ireturn from 0.2.1 to 0.2.2 (#4178)
  * build(deps): bump github.com/docker/docker from 23.0.3+incompatible to 24.0.7+incompatible in /tools (#4174)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.14.0 to 0.14.1 (#4171)
  * build(deps): bump google.golang.org/grpc from 1.55.0 to 1.56.3 in /tools (#4164)
  * docs: Update documentation and assets (#4163)
* Wed Oct 25 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.55.1:
  * output: convert backslashes to forward slashes for GitHub Action annotations printer (#4149)
  * build(deps): bump actions/setup-node from 3 to 4 (#4155)
  * build(deps): bump github.com/golangci/revgrep from v0.5.0 to v0.5.2 (#4154)
  * build(deps): bump github.com/securego/gosec/v2 from 2.18.1 to 2.18.2 (#4153)
  * docs: Update documentation and assets
  * docs: Update documentation and assets
* Fri Oct 20 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.55.0:
  * Add perfsprint linter (#3714)
  * docs: describe enabled and disabled by default analyzers of govet (#4146)
  * build(deps): bump github.com/uudashr/gocognit from 1.1.0 to 1.1.2 (#4145)
  * build(deps): bump github.com/uudashr/gocognit from 1.1.1 to 1.1.0 (#4144)
  * fix: update gofmt (#4141)
  * feat: add `sloglint` linter (#4133)
  * build(deps): bump github.com/4meepo/tagalign from 1.3.2 to 1.3.3 (#4143)
  * build(deps): bump github.com/butuzov/ireturn from 0.2.0 to 0.2.1 (#4142)
  * build(deps): bump @babel/traverse from 7.19.1 to 7.23.2 in /.github/peril (#4140)
  * build(deps): bump @babel/traverse from 7.20.5 to 7.23.2 in /docs (#4139)
  * docs: uppercase command option descriptions for consistency (#4135)
  * build(deps): bump github.com/ghostiam/protogetter from 0.2.2 to 0.2.3 (#4130)
  * build(deps): bump github.com/uudashr/gocognit from 1.0.7 to 1.1.1 (#4129)
  * build(deps): bump github.com/securego/gosec/v2 from 2.18.0 to 2.18.1 (#4131)
  * Add "inamedparam": checks for interface method with unnamed params (#3793)
  * govet: add `appends` analyzer (#4127)
  * build(deps): bump golang.org/x/net from 0.16.0 to 0.17.0 in /scripts/gen_github_action_config (#4125)
  * build(deps): bump golang.org/x/net from 0.10.0 to 0.17.0 in /tools (#4124)
  * build(deps): bump golang.org/x/oauth2 from 0.12.0 to 0.13.0 in /scripts/gen_github_action_config (#4122)
  * unused: support passing in options (#4086)
  * feat: add `gochecksumtype` linter (#3671)
  * add protogetter linter (#4069)
  * Add `testifylint` linter (#4103)
  * build(deps): bump github.com/securego/gosec/v2 from 2.17.0 to 2.18.0 (#4120)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.13.5 to 0.14.0 (#4117)
  * build(deps): bump golang.org/x/tools from 0.13.0 to 0.14.0 (#4119)
  * feat: update gofmt and goimports (#4115)
  * docs: add source options to exclude-rules docs (#4105)
  * docs: fix typos in testdata (#4116)
  * dev: enable gocheckcompilerdirectives linter (#4114)
  * build(deps): bump postcss from 8.4.20 to 8.4.31 in /docs (#4112)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.8 to 3.23.9 (#4111)
  * docs: add gosec G602 to includes/excludes inside .golangci.reference.yml (#4110)
  * dev: add missing test descriptions (#4107)
  * build(deps): bump github.com/Abirdcfly/dupword from 0.0.12 to 0.0.13 (#4104)
  * build(deps): bump github.com/breml/errchkjson from 0.3.5 to 0.3.6 (#4102)
  * build(deps): bump github.com/breml/bidichk from 0.2.6 to 0.2.7 (#4101)
  * dev: remove golangci-releaser from generated team (#4096)
  * build(deps): bump docker/setup-qemu-action from 2 to 3 (#4095)
  * build(deps): bump docker/build-push-action from 4 to 5 (#4094)
  * build(deps): bump github.com/mgechev/revive from 1.3.3 to 1.3.4 (#4087)
  * build(deps): bump docker/setup-buildx-action from 2 to 3 (#4093)
  * dev: refactor some test assertions (#4081)
  * build(deps): bump github.com/daixiang0/gci from 0.11.1 to 0.11.2 (#4090)
  * build(deps): bump honnef.co/go/tools from 0.4.5 to 0.4.6 (#4083)
  * build(deps): bump goreleaser/goreleaser-action from 4 to 5 (#4080)
  * build(deps): bump golang.org/x/oauth2 from 0.11.0 to 0.12.0 in /scripts/gen_github_action_config (#4079)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.4.4 to 1.4.5 (#4078)
  * build(deps): bump github.com/tetafro/godot from 1.4.14 to 1.4.15 (#4077)
  * Add a pre-commit hook to check all files (#4046)
  * build(deps): bump github.com/ryanrolds/sqlclosecheck from 0.4.0 to 0.5.1 (#4071)
  * build(deps): bump github.com/xen0n/gosmopolitan from 1.2.1 to 1.2.2 (#4070)
  * build(deps): bump github.com/daixiang0/gci from 0.11.0 to 0.11.1 (#4068)
  * build(deps): bump golang.org/x/tools from 0.12.0 to 0.13.0 (#4066)
  * build(deps): bump github.com/golangci/revgrep from 745bb2f7c2e6 to v0.5.0 (#4064)
  * build(deps): bump actions/checkout from 3 to 4 (#4065)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.7 to 3.23.8 (#4063)
  * build(deps): bump github.com/jgautheron/goconst from 1.5.1 to 1.6.0 (#4055)
  * build(deps): bump gitlab.com/bosi/decorder from 0.4.0 to 0.4.1 (#4056)
  * docs: fix a typo (#4048)
  * build(deps): bump github.com/breml/bidichk from 0.2.4 to 0.2.6 (#4044)
  * build(deps): bump github.com/mgechev/revive from 1.3.2 to 1.3.3 (#4043)
  * build(deps): bump github.com/breml/errchkjson from 0.3.1 to 0.3.5 (#4042)
  * build(deps): bump golangci/golangci-lint-action from 3.6.0 to 3.7.0 (#4036)
  * docs: Update documentation and assets (#4035)
* Mon Aug 21 2023 jkowalczyk@suse.com
- Update to version 1.54.2:
  * fix: add all directories as safe git directories inside the Docker image (#4034)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.4.3 to 1.4.4 (#4030)
  * govet: add directive and slog passes (#4028)
  * build(deps): bump github.com/tetafro/godot from 1.4.11 to 1.4.14 (#4029)
  * build(deps): bump github.com/securego/gosec/v2 from 2.16.0 to 2.17.0 (#4015)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.23.0 to 1.24.0 (#4016)
  * build(deps): bump github.com/Antonboom/errname from 0.1.10 to 0.1.12 (#4026)
  * build(deps): bump github.com/Antonboom/nilnil from 0.1.5 to 0.1.7 (#4024)
  * build(deps): bump honnef.co/go/tools from 0.4.4 to 0.4.5 (#4022)
  * dev: remove netlify (#4014)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.13.3 to 0.13.5 (#4019)
  * build(deps): bump honnef.co/go/tools from 0.4.3 to 0.4.4 (#4018)
  * build(deps): bump go.tmz.dev/musttag from 0.7.1 to 0.7.2 (#4017)
  * dev: packaging improvements (#4009)
  * dev: CI cleanups (#4008)
  * dev: improve issue form (#4005)
  * docs: Update documentation and assets (#4006)
* Sat Aug 12 2023 jkowalczyk@suse.com
- Update to version 1.54.1:
  * plugin: temporarily hide warning about using plugins using the old API (#4002)
  * build(deps): bump github.com/go-critic/go-critic from 0.8.2 to 0.9.0 (#4000)
  * build(deps): bump github.com/quasilyte/go-ruleguard from v0.3.19 to v0.4.0 (#3999)
  * docs: Update documentation and assets (#3997)
* Wed Aug  9 2023 jkowalczyk@suse.com
- Update to version 1.54.0:
  * fix: trim Go version (#3995)
  * go1.21 support (#3922)
  * build(deps): bump github.com/daixiang0/gci from 0.10.1 to 0.11.0 (#3994)
  * build(deps): bump golang.org/x/tools from 0.11.1 to 0.12.0 (#3992)
  * build(deps): bump golang.org/x/oauth2 from 0.10.0 to 0.11.0 in /scripts/gen_github_action_config (#3991)
  * build(deps): bump github.com/ultraware/funlen from 0.0.3 to 0.1.0 (#3988)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.6 to 3.23.7 (#3989)
  * build(deps): bump github.com/kunwardeep/paralleltest from 1.0.7 to 1.0.8 (#3985)
  * build(deps): bump github.com/4meepo/tagalign from 1.3.1 to 1.3.2 (#3980)
  * build(deps): bump github.com/4meepo/tagalign from 1.2.2 to 1.3.1 (#3979)
  * build(deps): bump github.com/go-critic/go-critic from 0.8.1 to 0.8.2 (#3978)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.13.0 to 0.13.3 (#3972)
  * dev: add tests for the new ginkgolinter's configuration (#3970)
  * build(deps): bump github.com/GaijinEntertainment/go-exhaustruct/v3 from 2.3.0 to 3.1.0 (#3963)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.12.2 to 0.13.0 (#3962)
  * build(deps): bump github.com/uudashr/gocognit from 1.0.6 to 1.0.7 (#3961)
  * build(deps): bump gitlab.com/bosi/decorder from 0.2.3 to 0.4.0 (#3959)
  * build(deps): bump word-wrap from 1.2.3 to 1.2.4 in /docs (#3956)
  * docs: add linters description (#3945)
  * build(deps): bump semver from 6.3.0 to 6.3.1 in /.github/peril (#3949)
  * build(deps): bump semver from 5.7.1 to 5.7.2 in /docs (#3950)
  * build(deps): bump semver from 5.7.0 to 5.7.2 in /tools (#3948)
  * build(deps): bump semver from 5.7.1 to 5.7.2 in /.github/contributors (#3947)
  * build(deps): bump golang.org/x/oauth2 from 0.9.0 to 0.10.0 in /scripts/gen_github_action_config (#3946)
  * build(deps): bump github.com/Abirdcfly/dupword from 0.0.11 to 0.0.12 (#3944)
  * build(deps): bump github.com/ashanbrown/forbidigo from 1.5.3 to 1.6.0 (#3942)
  * build(deps): bump golang.org/x/tools from 0.10.0 to 0.11.0 (#3943)
  * dev: improve bug report template (#3930)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.4.2 to 1.4.3 (#3935)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.12.1 to 0.12.2 (#3937)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.5 to 3.23.6 (#3936)
  * feat: explain typecheck and remove it from the linter list (#3929)
  * build(deps): bump go.tmz.dev/musttag from 0.7.0 to 0.7.1 (#3924)
  * build(deps): bump github.com/ykadowak/zerologlint from 0.1.2 to 0.1.3 (#3923)
  * chore: fix nancy
  * build(deps): bump golang.org/x/oauth2 from 0.8.0 to 0.9.0 in /scripts/gen_github_action_config (#3920)
  * build(deps): bump github.com/golangci/misspell 0.4.0 to 0.4.1 (#3918)
  * gofmt: autofix missing newline at EOF (#3917)
  * build(deps): bump golang.org/x/tools from 0.9.3 to 0.10.0 (#3914)
  * fix: include custom linters in `enable-all` (#3911)
  * docs: Update documentation and assets (#3909)
  * plugin: allow to use settings for plugins (#3887)
- Packaging: Update LICENSE to %%license from %%doc
* Wed Aug  9 2023 jkowalczyk@suse.com
- Update to version 1.53.3:
  * Add support for generating illumos/amd64 targeted builds (#3907)
  * build(deps): bump github.com/alexkohler/nakedret/v2 from 2.0.1 to 2.0.2 (#3905)
  * build(deps): bump github.com/ashanbrown/forbidigo from 1.5.1 to 1.5.3 (#3904)
  * dev: simplify GetAllSupportedLinterConfigs method (#3901)
  * build(deps): bump golangci/golangci-lint-action from 3.5.0 to 3.6.0 (#3903)
  * build(deps): bump actions/setup-go from 3 to 4 (#3902)
  * build(deps): bump github.com/BurntSushi/toml from 1.3.0 to 1.3.2 (#3899)
  * build(deps): bump github.com/nishanths/exhaustive from 0.10.0 to 0.11.0 (#3900)
  * ineffassign: bump to HEAD (#3898)
  * build(deps): bump gatsby from 4.25.0 to 4.25.7 in /docs (#3896)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.12.2 to 0.12.1 (#3892)
  * build(deps): bump golangci/golangci-lint-action from 3.4.0 to 3.5.0 (#3890)
  * dev: use to GitHub Pages (#3884)
  * build(deps): bump github.com/ykadowak/zerologlint from 0.1.1 to 0.1.2 (#3889)
  * build(deps): bump github.com/bkielbasa/cyclop from 1.2.0 to 1.2.1 (#3888)
  * build(deps): bump github.com/sirupsen/logrus from 1.9.2 to 1.9.3 (#3886)
  * dev: tidy go deps (#3885)
  * codeclimate: less memory allocation (#3882)
  * docs: Update documentation and assets
* Sat Jun  3 2023 jkowalczyk@suse.com
- Update to version 1.53.2:
  * build(deps): bump github.com/OpenPeeDeeP/depguard/v2 from v2.0.1 to 2.1.0 (#3883)
  * depguard: throw error only when the linter is called (#3880)
  * docs: fix default depguard rule (#3879)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.4 to 3.23.5 (#3875)
  * build(deps): bump golang.org/x/tools from 0.9.2 to 0.9.3 (#3874)
  * build(deps): bump @emotion/react from 11.10.8 to 11.11.0 in /docs (#3863)
  * dev: update Changelog
  * docs: Update documentation and assets (#3873)
* Sat Jun  3 2023 jkowalczyk@suse.com
- Update to version 1.53.1:
  * importas: fix duplication detection when aliases use regular expression replacement pattern (#3869)
  * depguard: fix GOROOT detection (#3866)
  * docs: Update documentation and assets
* Thu Jun  1 2023 jkowalczyk@suse.com
- Update to version 1.53.0:
  * mirror: linter that suggest using alternative string/[]byte functions (#3825)
  * build(deps): bump github.com/BurntSushi/toml from 1.2.1 to 1.3.0 (#3860)
  * build(deps): bump github.com/kunwardeep/paralleltest from 1.0.6 to 1.0.7 (#3859)
  * build(deps): bump golang.org/x/tools from 0.9.1 to 0.9.2 (#3858)
  * build(deps): bump github.com/stretchr/testify from 1.8.3 to 1.8.4 (#3857)
  * dev: simplify issues and enabled set tests (#3832)
  * forbidigo: better support for configuring complex rules (#3612)
  * rules: support inverted path match (#3617)
  * build(deps): bump go.tmz.dev/musttag from 0.6.1 to 0.7.0 (#3853)
  * docs: update supported Go versions FAQ (#3852)
  * build(deps): bump github.com/sigstore/rekor from 1.1.1 to 1.2.0 in /tools (#3851)
  * build(deps): bump github.com/goreleaser/nfpm/v2 from 2.25.1 to 2.29.0 in /tools (#3847)
  * build(deps): bump github.com/securego/gosec/v2 from 2.15.0 to 2.16.0 (#3843)
  * build(deps): bump github.com/mgechev/revive from 1.3.1 to 1.3.2 (#3845)
  * build(deps): bump github.com/stretchr/testify from 1.8.2 to 1.8.3 (#3844)
  * build(deps): bump github.com/go-critic/go-critic from 0.8.0 to 0.8.1 (#3842)
  * build(deps): bump github.com/sirupsen/logrus from 1.9.0 to 1.9.2 (#3841)
  * build(deps): bump golang.org/x/oauth2 from 0.7.0 to 0.8.0 in /scripts/gen_github_action_config (#3838)
  * build(deps): bump github.com/Antonboom/nilnil from 0.1.4 to 0.1.5 (#3836)
  * build(deps): bump github.com/Antonboom/errname from 0.1.9 to 0.1.10 (#3834)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.4.1 to 1.4.2 (#3837)
  * build(deps): bump golang.org/x/tools from 0.8.0 to 0.9.1 (#3835)
  * dev: replace sliceutil package with exp/slices (#3830)
  * build(deps): bump github.com/docker/distribution from 2.8.1+incompatible to 2.8.2+incompatible in /tools (#3831)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.11.2 to 0.12.0 (#3822)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.4.0 to 1.4.1 (#3821)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.3 to 3.23.4 (#3823)
  * build(deps): bump go.tmz.dev/musttag from 0.6.0 to 0.6.1 (#3824)
  * build(deps): bump github.com/docker/docker from 23.0.1+incompatible to 23.0.3+incompatible in /tools (#3818)
  * build(deps): bump github.com/sigstore/rekor from 0.12.1-0.20220915152154-4bb6f441c1b2 to 1.1.1 in /tools (#3817)
  * doc: update tagliatelle documentation (#3816)
  * build(deps): bump @emotion/react from 11.10.4 to 11.10.8 in /docs (#3812)
  * build(deps): bump github.com/go-critic/go-critic from 0.7.0 to 0.8.0 (#3810)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.11.0 to 0.11.2 (#3811)
  * docs: clarify mnd ignore usage examples to be regexps (#3805)
  * ireturn: update tests & docs (#3800)
  * docs: Fix minor typo in new-linters.mdx (#3799)
  * depguard: migrate to v2 (#3795)
  * usestdlibvars: fix configuration (#3797)
  * build(deps): bump github.com/butuzov/ireturn from 0.1.1 to 0.2.0 (#3794)
  * bodyclose: bump to HEAD (#3792)
  * gci: improve error message (#3777)
  * gosec: convert global settings as map with proper key type (#3779)
  * build(deps): bump go.tmz.dev/musttag from 0.5.0 to 0.6.0 (#3791)
  * build(deps): bump gatsby-plugin-sharp from 4.25.0 to 4.25.1 in /docs (#3790)
  * dev: remove unused ctx parameter from Printer (#3761)
  * add linter zerologlint (#3726)
  * build(deps): bump github.com/ldez/tagliatelle from 0.4.0 to 0.5.0 (#3782)
  * dev: add gofmt rewrite rule to ensure 'any' is always used (#3780)
  * docs: improve features section (#3781)
  * build(deps): bump github.com/alexkohler/nakedret to 2.0.1 (#3760)
  * build(deps): bump peter-evans/create-pull-request from 4 to 5 (#3774)
  * build(deps): bump golang.org/x/oauth2 from 0.6.0 to 0.7.0 in /scripts/gen_github_action_config (#3773)
  * build(deps): bump mvdan.cc/gofumpt from 0.4.0 to 0.5.0 (#3772)
  * build(deps): bump github.com/spf13/cobra from 1.6.1 to 1.7.0 (#3771)
  * build(deps): bump golang.org/x/tools from 0.7.0 to 0.8.0 (#3770)
  * build(deps): bump github.com/docker/docker from 20.10.21+incompatible to 20.10.24+incompatible in /tools (#3765)
  * importas: fix typo in logs (#3762)
  * importas: detect duplicate alias or package in the configuration (#3753)
  * output: add colored-tab (#3729)
  * build(deps): bump gatsby-remark-responsive-iframe from 5.24.0 to 5.25.0 in /docs (#3750)
  * dev: enable revive linter with default config (#3622)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.2 to 3.23.3 (#3754)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.10.0 to 0.11.0 (#3756)
  * build(deps): bump github.com/Antonboom/nilnil from 0.1.3 to 0.1.4 (#3755)
  * feat: remove warning when the config file is explicitly stdin (#3740)
  * dev: gofmt -w -r 'interface{} -> any' pkg scripts (#3742)
  * dev: remove golangci-releaser from generated team (#3744)
  * add loongarch64 to the install script (#3741)
  * tests: remove go version restrictions (#3730)
  * ginkgolinter: add suppress-async-assertion option (#3735)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.9.0 to 0.10.0 (#3734)
  * add tagalign linter (#3709)
  * build(deps): bump github.com/nishanths/exhaustive from 0.9.5 to 0.10.0 (#3733)
  * build(deps): bump github.com/sivchari/containedctx from 1.0.2 to 1.0.3 (#3732)
  * feat: add the gosmopolitan linter (#3458)
  * docs: Update documentation and assets (#3731)
  * docs: Update documentation and assets
* Thu Jun  1 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Use _service mode manual as better alias name than disabled
* Sat Mar 25 2023 jkowalczyk@suse.com
- Update to version 1.52.2:
  * build(deps): bump github.com/moricho/tparallel from 0.3.0 to 0.3.1 (#3719)
  * fix(pre-commit): require_serial & pass_filenames (#3713)
  * docs: Update documentation and assets
* Tue Mar 21 2023 jkowalczyk@suse.com
- Update to version 1.52.1:
  * fix: combination of --fix and --path-prefix (#3700)
  * fix: improve panic management (#3710)
  * build(deps): bump actions/setup-go from 3 to 4 (#3707)
  * docs: fix typos (#3705)
  * docs: Update documentation and assets
- Packaging: _service add set_version to automate version updates
* Tue Mar 21 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Use SOURCE_DATE_EPOCH as build date (boo#1047218)
* Sat Mar 18 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Normalize _service modes localonly and manual to disabled to
  prevent errors on package version updates. tar_scm, recompress
  and go_modules are intended to be run together.
* Sat Mar 18 2023 jkowalczyk@suse.com
- Update to version 1.52.0:
  * docs: remove unused from config.LintersSettings (#3704)
  * build(deps): bump github.com/mgechev/revive from 1.3.0 to 1.3.1 (#3702)
  * fix: consider path prefix when matching path patterns (#3571)
  * build(deps): bump github.com/go-critic/go-critic from 0.6.7 to 0.7.0 (#3701)
  * build(deps): bump honnef.co/go/tools from 0.4.2 to 0.4.3 (#3699)
  * build(deps): bump github.com/mgechev/revive from 1.2.5 to 1.3.0 (#3698)
  * godox: bump to HEAD (#3697)
  * build(deps): bump github.com/sonatard/noctx from 0.0.1 to 0.0.2 (#3696)
  * rowserrcheck: remove limitation related to generics support (#3691)
  * build(deps): bump github.com/tdakkota/asciicheck from 0.1.1 to 0.2.0 (#3694)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.3.0 to 1.4.0 (#3695)
  * build(deps): bump github.com/kkHAIKE/contextcheck from 1.1.3 to 1.1.4 (#3693)
  * build(deps): bump webpack from 5.68.0 to 5.76.1 in /docs (#3692)
  * wastedassign: remove limitation related to generics support (#3689)
  * doc: enhance errcheck description (#3688)
  * build(deps): bump github.com/daixiang0/gci from 0.9.1 to 0.10.1 (#3686)
  * build(deps): bump github.com/moricho/tparallel from 0.2.1 to 0.3.0 (#3687)
  * build(deps): bump github.com/Abirdcfly/dupword from 0.0.9 to 0.0.11 (#3685)
  * build(deps): bump github.com/breml/errchkjson from 0.3.0 to 0.3.1 (#3684)
  * build(deps): bump github.com/Antonboom/nilnil from 0.1.2 to 0.1.3 (#3679)
  * build(deps): bump github.com/fatih/color from 1.14.1 to 1.15.0 (#3681)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.2.0 to 1.3.0 (#3675)
  * build(deps): bump github.com/breml/bidichk from 0.2.3 to 0.2.4 (#3680)
  * build(deps): bump gatsby-plugin-sharp from 4.24.0 to 4.25.0 in /docs (#3677)
  * build(deps): bump github.com/maratori/testpackage from 1.1.0 to 1.1.1 (#3676)
  * build(deps): bump github.com/Antonboom/errname from 0.1.8 to 0.1.9 (#3672)
  * docs: remove description for deprecated "go" option (#3667)
  * build(deps): bump sonatype-nexus-community/nancy-github-action from 1.0.2 to 1.0.3 (#3665)
  * build(deps): bump golang.org/x/oauth2 from 0.5.0 to 0.6.0 in /scripts/gen_github_action_config (#3664)
  * feat: check only changed files in pre-commit hook (#3521)
  * build(deps): bump github.com/Antonboom/errname from 0.1.7 to 0.1.8 (#3660)
  * build(deps): bump github.com/charithe/durationcheck from 0.0.9 to 0.0.10 (#3661)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.23.1 to 3.23.2 (#3659)
  * build(deps): bump github.com/Antonboom/nilnil from 0.1.1 to 0.1.2 (#3658)
  * build(deps): bump github.com/timonwong/loggercheck from 0.9.3 to 0.9.4 (#3657)
  * doc: remove from FAQ golangci.com mention (#3655)
  * doc: replace golang with Go in descriptions for gci, thelper, goerr113 (#3651)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.8.1 to 0.9.0 (#3643)
  * build(deps): bump golang.org/x/net from 0.0.0-20220805013720-a33c5aa5df48 to 0.7.0 in /tools (#3648)
  * build(deps): bump golang.org/x/net from 0.0.0-20220624214902-1bab6f366d9e to 0.7.0 in /scripts/gen_github_action_config (#3647)
  * build(deps): bump gatsby-transformer-yaml from 4.21.0 to 4.25.0 in /docs (#3646)
  * dev: add Go version to version information (#3625)
  * doc: add Tekton in Trusted By page (#3645)
  * docs: Clarify that custom linters are not enabled by default (#3506)
  * build(deps): bump github.com/ashanbrown/forbidigo from 1.4.0 to 1.5.1 (#3639)
  * dev: remove github.com/pkg/errors inside tests (#3642)
  * feat: add TeamCity output format (#3606)
  * dev: git ignore golangci-lint.exe on Windows (#3641)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.1.0 to 1.2.0 (#3636)
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.8.0 to 2.8.1 (#3640)
  * build(deps): bump github.com/stretchr/testify from 1.8.1 to 1.8.2 (#3637)
  * dev: bytes.NewBuffer/bytes.NewBufferString to shorten initialization (#3632)
  * build(deps): bump github.com/junk1tm/musttag from 0.4.5 to 0.5.0 (#3624)
  * lll: skip go command (#3572)
  * dev: replace pkg/errors with native error wrapping (#3604)
  * chore: fix nancy
  * docs: Update documentation and assets (#3619)
* Sat Mar 18 2023 jkowalczyk@suse.com
- Update to version 1.51.2:
  * build(deps): bump github.com/go-critic/go-critic from 0.6.6 to 0.6.7 (#3618)
  * build(deps): bump github.com/go-critic/go-critic from 0.6.5 to 0.6.6 (#3616)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.22.0 to 1.23.0 (#3615)
  * doc: improve installation section (#3610)
  * fix: cache status size calculation (#3611)
  * dev: remove duplicated test asserts (#3608)
  * dev: add new source archive (#3585)
  * govet: enable timeformat by default (#3602)
  * build(deps): bump honnef.co/go/tools from 0.4.1 to 0.4.2 (#3599)
  * build(deps): bump github.com/junk1tm/musttag from 0.4.4 to 0.4.5 (#3598)
  * dev: do not print extra whitespace in deprecated lint log (#3596)
  * docs: remove trailing whitespaces (#3593)
  * build(deps): bump github.com/ashanbrown/forbidigo from 1.3.0 to 1.4.0 (#3590)
  * build(deps): bump honnef.co/go/tools from 0.4.0 to 0.4.1 (#3591)
  * build(deps): bump golang.org/x/tools from 0.5.0 to 0.6.0 (#3587)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.0.6 to 1.1.0 (#3588)
  * docs: Replace links to godoc.org with pkg.go.dev (#3584)
  * doc: update contact email
  * build(deps): bump @sideway/formula from 3.0.0 to 3.0.1 in /docs (#3579)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.21.1 to 1.22.0 (#3574)
  * build(deps): bump github.com/securego/gosec/v2 from 2.14.0 to 2.15.0 (#3577)
  * build(deps): bump github.com/bombsimon/wsl/v3 from 3.3.0 to 3.4.0 (#3575)
  * build(deps): bump github.com/daixiang0/gci from 0.9.0 to 0.9.1 (#3576)
  * build(deps): bump gatsby-plugin-canonical-urls from 4.22.0 to 4.25.0 in /docs (#3531)
  * build(deps): bump gatsby-transformer-remark from 5.21.0 to 5.25.1 in /docs (#3450)
  * docs: Update documentation and assets (#3566)
* Sat Mar 18 2023 jkowalczyk@suse.com
- Update to version 1.51.1:
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.7.0 to 2.8.0 (#3563)
  * build(deps): bump github.com/junk1tm/musttag from 0.4.3 to 0.4.4 (#3564)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.8.0 to 0.8.1 (#3562)
  * dev: replace deprecated command with environment file (#3558)
  * build(deps): bump github.com/go-toolsmith/astcopy from v1.0.2 to v1.0.3 (#3560)
  * staticcheck: bump to v0.4.0 (#3551)
  * ineffassign: bump to HEAD (#3550)
  * ginkgolinter: fix panic (#3553)
  * build(deps): bump github.com/ryanrolds/sqlclosecheck from 0.3.0 to 0.4.0 (#3545)
  * build(deps): bump github.com/sanposhiho/wastedassign/v2 from 2.0.6 to 2.0.7 (#2160)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.12 to 3.23.1 (#3544)
  * dev: use Go1.20 to run tests with the latest golangci-lint version (#3540)
  * docs: Update documentation and assets (#3539)
* Sat Mar 18 2023 jkowalczyk@suse.com
- Update to version 1.51.0:
  * build(deps): bump http-cache-semantics from 4.1.0 to 4.1.1 in /docs (#3537)
  * go1.20 support (#3414)
  * build(deps): bump docker/build-push-action from 3 to 4 (#3522)
  * build(deps): bump github.com/ryancurrah/gomodguard from 1.2.4 to 1.3.0 (#3518)
  * build(deps): bump github.com/mgechev/revive from 1.2.4 to 1.2.5 (#3517)
  * docs: update output example to use valid checkstyle example; add json example (#3516)
  * build(deps): bump 4d63.com/gocheckcompilerdirectives from 1.2.0 to 1.2.1 (#3519)
  * build(deps): bump github.com/fatih/color from 1.13.0 to 1.14.1 (#3520)
  * chore: fix install script (revert) (#3514)
  * chore: fix latest install to cater for existing users who installed using '-s latest' (#3513)
  * chore: fix install.sh to point at releases API (#3510)
  * build(deps): bump ua-parser-js from 0.7.31 to 0.7.33 in /docs (#3508)
  * build(deps): bump 4d63.com/gochecknoglobals from 0.1.0 to 0.2.1 (#3496)
  * build(deps): bump golangci/golangci-lint-action from 3.3.1 to 3.4.0 (#3501)
  * build(deps): bump github.com/junk1tm/musttag from 0.4.1 to 0.4.3 (#3499)
  * build(deps): bump github.com/nunnatsa/ginkgolinter from 0.6.0 to 0.7.1 (#3500)
  * build(deps): bump 4d63.com/gocheckcompilerdirectives from 1.1.0 to 1.2.0 (#3497)
  * chore: Do not use methods on pointer and value receivers (#3321)
  * feat: add gocheckcompilerdirectives (#3463)
  * feat: add musttag linter (#3386)
  * ci: support building loong64 release binaries (#3459)
  * build(deps): bump github.com/ldez/tagliatelle from 0.3.1 to 0.4.0 (#3483)
  * build(deps): bump github.com/kisielk/errcheck from 1.6.2 to 1.6.3 (#3482)
  * docs: add note about binary requirement for plugin (#3468)
  * build(deps): bump golang.org/x/tools from 0.4.0 to 0.5.0 (#3465)
  * unparam: bump to HEAD (#3452)
  * build(deps): bump react-headroom from 3.2.0 to 3.2.1 in /docs (#3448)
  * build(deps): bump gatsby-remark-images from 6.21.0 to 6.25.0 in /docs (#3447)
  * build(deps): bump github.com/quasilyte/go-ruleguard/dsl from 0.3.21 to 0.3.22 (#3443)
  * build(deps): bump json5 from 2.2.1 to 2.2.3 in /.github/peril (#3446)
  * build(deps): bump github.com/nishanths/exhaustive from 0.9.3 to 0.9.5 (#3444)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.10 to 3.22.12 (#3445)
  * Build NetBSD binaries (#3442)
  * doc: improve documentation about debugging. (#3434)
  * doc: More specific default cache directory (#3418)
  * build(deps): bump minimatch, recursive-readdir and gatsby-plugin-google-analytics in /docs (#3436)
  * Add timeformat to govet analysers (#3353)
  * Add the ginkgolinter linter (#3369)
  * unparam: bump to HEAD (#3429)
  * build(deps): bump goreleaser/goreleaser-action from 3 to 4 (#3427)
  * doc: usage typo in tagliatelle (#3423)
  * build(deps): bump github.com/Abirdcfly/dupword from 0.0.8 to 0.0.9 (#3422)
  * doc: cache preserving and colored output on docker runs (#3377)
  * doc: improve documentation for goimport local-prefixes (#3349)
  * build(deps): bump gatsby from 4.19.2 to 4.25.0 in /docs (#3416)
  * build(deps): bump postcss from 8.4.18 to 8.4.20 in /docs (#3417)
  * build(deps): bump express from 4.17.2 to 4.18.2 in /docs (#3412)
  * build(deps): bump gatsby-plugin-manifest from 4.21.0 to 4.25.0 in /docs (#3415)
  * build(deps): bump decode-uri-component from 0.2.0 to 0.2.2 in /docs (#3394)
  * build(deps): bump react-icons from 4.4.0 to 4.7.1 in /docs (#3389)
  * wsl: fix force-err-cuddling flag (#3407)
  * build(deps): bump golang.org/x/tools from 0.3.0 to 0.4.0 (#3411)
  * feat: remove deprecated linters from presets (#3405)
  * Revert "build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.10 to 3.22.11" (#3397)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.10 to 3.22.11 (#3393)
  * build(deps): bump github.com/nishanths/exhaustive from 0.9.2 to 0.9.3 (#3392)
  * build(deps): bump github.com/timakin/bodyclose to HEAD (#3378)
  * build(deps): bump github.com/nishanths/exhaustive from 0.8.3 to 0.9.2 (#3381)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.0.5 to 1.0.6 (#3380)
  * build(deps): bump github.com/daixiang0/gci from 0.8.5 to 0.9.0 (#3379)
  * build(deps): bump minimatch from 3.0.4 to 3.1.2 in /tools (#3373)
  * build(deps): bump github.com/leonklingele/grouper from 1.1.0 to 1.1.1 (#3372)
  * build(deps): bump github.com/kyoh86/exportloopref from 0.1.9 to 0.1.11 (#3368)
  * build(deps): bump github.com/daixiang0/gci from 0.8.2 to 0.8.5 (#3367)
  * build(deps): bump golangci/golangci-lint-action from 3.3.0 to 3.3.1 (#3360)
  * build(deps): bump golang.org/x/tools from 0.2.0 to 0.3.0 (#3358)
  * chore: Add a clarifying note to the bug report template (#3355)
  * build(deps): bump socket.io-parser from 4.0.4 to 4.0.5 in /docs (#3352)
  * build(deps): bump github.com/sourcegraph/go-diff to HEAD (#3350)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.9 to 3.22.10 (#3347)
  * doc: improve Editor Integration section (#3307)
  * build(deps): bump ansi-regex from 4.1.0 to 5.0.1 in /docs (#3344)
  * docs: fix typo in nolint (#3345)
  * build(deps): bump gatsby-plugin-sharp from 4.19.0 to 4.24.0 in /docs (#3343)
  * build(deps): bump gatsby-plugin-sitemap from 5.21.0 to 5.24.0 in /docs (#3342)
  * build(deps): bump gatsby-plugin-emotion from 7.21.0 to 7.24.0 in /docs (#3341)
  * build(deps): bump postcss from 8.4.16 to 8.4.18 in /docs (#3340)
  * build(deps): bump github.com/spf13/cobra from 1.6.0 to 1.6.1 (#3334)
  * build(deps): bump github.com/Abirdcfly/dupword from 0.0.7 to 0.0.8 (#3333)
  * build(deps): bump github.com/stretchr/testify from 1.8.0 to 1.8.1 (#3332)
  * build(deps): bump github.com/sivchari/tenv from 1.7.0 to 1.7.1 (#3331)
  * build(deps): bump github.com/daixiang0/gci from 0.8.1 to 0.8.2 (#3330)
  * build(deps): bump golangci/golangci-lint-action from 3.2.0 to 3.3.0 (#3323)
  * chore: add changelog
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.20.0 to 1.21.1 (#3318)
  * build(deps): bump github.com/kyoh86/exportloopref from 0.1.8 to 0.1.9 (#3317)
  * docs(gomnd): add missing always ignored functions (#3315)
  * build(deps): bump github.com/securego/gosec/v2 from 2.13.1 to 2.14.0 (#3311)
  * docs: Update documentation and assets (#3314)
* Mon Oct 24 2022 jkowalczyk@suse.com
- Update to version 1.50.1:
  * build(deps): bump github.com/daixiang0/gci from 0.8.0 to 0.8.1 (#3309)
  * build(deps): bump golang.org/x/tools from 0.1.12 to 0.2.0 (#3312)
  * build(deps): bump github.com/BurntSushi/toml from 1.2.0 to 1.2.1 (#3310)
  * code-climate: add default severity (#3294)
  * doc: improved wording (#3302)
  * build(deps): bump parse-url and gatsby-telemetry in /docs (#3306)
  * build(deps): bump github.com/kkHAIKE/contextcheck from 1.1.2 to 1.1.3 (#3296)
  * build(deps): bump github.com/tommy-muehle/go-mnd/v2 from 2.5.0 to 2.5.1 (#3295)
  * chore: update go.mod for gen_github_action_config script (#3300)
  * build(deps): bump github.com/spf13/cobra from 1.5.0 to 1.6.0 (#3298)
  * lll: skip imports (#3288)
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.6.2 to 2.7.0 (#3287)
  * revive: fix configuration parsing (#3284)
  * fix: remove redundant character escape '\/' (#3278)
  * docs: Update documentation and assets (#3274)
* Mon Oct 24 2022 jkowalczyk@suse.com
- Update to version 1.50.0:
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.8 to 3.22.9 (#3267)
  * build(deps): bump eventsource and @graphql-tools/url-loader in /docs (#3266)
  * build(deps): bump gatsby-remark-autolink-headers from 5.15.1 to 5.24.0 in /docs (#3265)
  * build(deps): bump gatsby-remark-copy-linked-files from 5.22.0 to 5.24.0 in /docs (#3263)
  * build(deps): bump @emotion/react from 11.9.0 to 11.10.4 in /docs (#3262)
  * build(deps): bump gatsby-plugin-offline from 5.19.0 to 5.24.0 in /docs (#3261)
  * build(deps): bump gatsby-remark-responsive-iframe from 5.21.0 to 5.24.0 in /docs (#3260)
  * build(deps): bump github.com/mgechev/revive from 1.2.3 to 1.2.4 (#3257)
  * build(deps): bump mvdan.cc/gofumpt from 0.3.1 to 0.4.0 (#3256)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.19.1 to 1.20.0 (#3255)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.0.4 to 1.0.5 (#3254)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.19.0 to 1.19.1 (#3242)
  * build(deps): bump github.com/daixiang0/gci from 0.7.0 to 0.8.0 (#3241)
  * build(deps): bump github.com/kkHAIKE/contextcheck from 1.1.1 to 1.1.2 (#3243)
  * build(deps): bump cross-fetch and graphql-config in /docs (#3239)
  * build(deps): bump jpeg-js and @jimp/jpeg in /docs (#3238)
  * build(deps): bump jsdom and jest in /.github/peril (#3237)
  * build(deps): bump github.com/curioswitch/go-reassign v0.1.2 to v0.2.0 (#3234)
  * paralleltest: add tests of the ignore-missing option (#3233)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.0.3 to 1.0.4 (#3226)
  * feat: add linter dupword (#3192)
  * dev: add riscv64 to the install script (#3220)
  * docs: specify what code checks are related to staticcheck sub-linter (#3215)
  * dev: add doc about internal package extracted from Go (#3204)
  * wsl: support all configs and update docs (#3202)
  * dev: improve tests on Windows (#3211)
  * exhaustive: add missing config (#3212)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.17.1 to 1.19.0 (#3206)
  * build(deps): bump github.com/nishanths/exhaustive from 0.8.1 to 0.8.3 (#3207)
  * build(deps): bump parse-path from 4.0.4 to 5.0.0 in /docs (#3210)
  * build(deps): bump github.com/kkHAIKE/contextcheck from 1.1.0 to 1.1.1 (#3208)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.0.2 to 1.0.3 (#3209)
  * build(deps): bump github.com/spf13/viper from 1.12.0 to 1.13.0 (#3205)
  * contextcheck: change owner (#3198)
  * feat: add testableexamples linter (#3170)
  * feat: rename logrlint to loggercheck (#3144)
  * dev: reference all the debug keys and env vars (#3196)
  * interfacebloat: fix configuration loading (#3194)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.14.0 to 1.17.1 (#3188)
  * build(deps): bump github.com/daixiang0/gci from 0.6.3 to 0.7.0 (#3190)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.7 to 3.22.8 (#3187)
  * build(deps): bump github.com/sylvia7788/contextcheck from 1.0.8 to 1.0.9 (#3189)
  * build(deps): bump github.com/OpenPeeDeeP/depguard from 1.1.0 to 1.1.1 (#3186)
  * build(deps): bump gatsby-source-filesystem from 4.21.1 to 4.22.0 in /docs (#3179)
  * build(deps): bump gatsby-plugin-canonical-urls from 4.21.0 to 4.22.0 in /docs (#3182)
  * build(deps): bump gatsby-remark-copy-linked-files from 5.21.0 to 5.22.0 in /docs (#3181)
  * build(deps): bump gatsby-plugin-google-analytics from 4.17.0 to 4.22.0 in /docs (#3180)
  * dev: review and clean linter tests (#3139)
  * feat: update gofmt and goimports and add option "rewrite-rules" (#3174)
  * cli: remove reference to old service (#3173)
  * build(deps): bump gatsby-plugin-sitemap from 5.13.0 to 5.21.0 in /docs (#3169)
  * build(deps): bump gatsby-plugin-canonical-urls from 4.13.0 to 4.21.0 in /docs (#3168)
  * build(deps): bump @emotion/styled from 11.8.1 to 11.10.0 in /docs (#3167)
  * build(deps): bump gatsby-plugin-catch-links from 4.17.0 to 4.21.0 in /docs (#3164)
  * build(deps): bump react-icons from 4.3.1 to 4.4.0 in /docs (#3155)
  * build(deps): bump prism-react-renderer from 1.3.3 to 1.3.5 in /docs (#3165)
  * build(deps): bump gatsby-plugin-react-helmet from 5.19.0 to 5.21.0 in /docs (#3163)
  * build(deps): bump gatsby-transformer-yaml from 4.19.0 to 4.21.0 in /docs (#3162)
  * build(deps): bump gatsby-source-filesystem from 4.13.0 to 4.21.1 in /docs (#3161)
  * build(deps): bump gatsby-remark-images from 6.15.1 to 6.21.0 in /docs (#3160)
  * build(deps): bump gatsby-transformer-sharp from 4.19.0 to 4.21.0 in /docs (#3156)
  * build(deps): bump gatsby-plugin-emotion from 7.19.0 to 7.21.0 in /docs (#3159)
  * build(deps): bump gatsby-remark-copy-linked-files from 5.17.0 to 5.21.0 in /docs (#3157)
  * build(deps): bump postcss from 8.4.14 to 8.4.16 in /docs (#3158)
  * build(deps): bump react-dom from 18.1.0 to 18.2.0 in /docs (#3154)
  * build(deps): bump github.com/go-critic/go-critic from 0.6.4 to 0.6.5 (#3150)
  * build(deps): bump gatsby-transformer-remark from 5.13.0 to 5.21.0 in /docs (#3153)
  * build(deps): bump gatsby-remark-responsive-iframe from 5.13.0 to 5.21.0 in /docs (#3152)
  * build(deps): bump gatsby-plugin-manifest from 4.15.1 to 4.21.0 in /docs (#3151)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.13.0 to 1.14.0 (#3147)
  * build(deps): bump github.com/sylvia7788/contextcheck from 1.0.6 to 1.0.8 (#3148)
  * docs: link fixes (#3142)
  * dev: fix CI workflow for Windows (#3134)
  * Normalize exclude-rules paths for Windows (#2387)
  * docs: Update documentation and assets (#3130)
* Mon Oct 24 2022 jkowalczyk@suse.com
- Update to version 1.49.0:
  * contextcheck: bump to v1.0.6 && re-enable (#3102)
  * feat: add reassign linter (#3064)
  * dev: fix linter tests (#3128)
  * feat: add logrlint (#3093)
  * dev: concat string
  * fix: flaky tests
  * feat: deprecate varcheck, deadcode, and structcheck (#3125)
  * dev: improve runner to run dir with go.mod (#3124)
  * fix: set an explicit GOROOT in the Docker image for go-critic (#3106)
  * feat: add interfacebloat (#3024)
  * build(deps): bump github.com/mattn/go-colorable from 0.1.12 to 0.1.13 (#3123)
  * build(deps): bump github.com/GaijinEntertainment/go-exhaustruct/v2 from 2.2.2 to 2.3.0 (#3122)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.10.0 to 1.13.0 (#3120)
  * dev: fix output tests (#3118)
  * build(deps): bump github.com/securego/gosec/v2 from 2.12.0 to 2.13.1 (#3119)
  * docs: add a section about default exclusions (#3117)
  * dev: follow standards by using 'want' instead of 'ERROR' for tests (#3104)
  * docs: wrong URL in .golangci.reference.yml (#3113)
  * dev: rewrite the tests framework (#3100)
  * dev: replace golangcitest:config by golangcitest:config_path (#3099)
  * build(deps): bump github.com/go-critic/go-critic from 0.6.3 to 0.6.4 (#3089)
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.0.1 to 1.0.2 (#3097)
  * docs: remove allow-leading-space option (#3072)
  * fix: go.sum
  * build(deps): bump github.com/polyfloyd/go-errorlint from 1.0.0 to 1.0.1 (#3092)
  * build(deps): bump github.com/sashamelentyev/usestdlibvars from 1.8.0 to 1.10.0 (#3090)
  * build(deps): bump github.com/mgechev/revive from 1.2.2 to 1.2.3 (#3091)
  * docs: fix typo in usestdlibvars documentation (#3078)
  * build(deps): bump github.com/mgechev/revive from 1.2.1 to 1.2.2 (#3075)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.6 to 3.22.7 (#3074)
  * fix: exit early on run --version (#3067)
  * nosnakecase: deprecate linter (#3065)
  * docs: Update documentation and assets (#3062)
* Mon Oct 24 2022 jkowalczyk@suse.com
- Update to version 1.48.0:
  * build(deps): bump github.com/daixiang0/gci from 0.6.0 to 0.6.2 (#3058)
  * build(deps): bump github.com/kisielk/errcheck from 1.6.1 to 1.6.2 (#3059)
  * build(deps): bump revgrep to HEAD (#3054)
  * dev: remove stable from actions/setup-go (#3055)
  * feat: go1.19 support  (#3037)
  * contextcheck: disable linter (#3050)
  * feat: add usestdlibvars (#3016)
  * gci: add missing `custom-order` setting (#3052)
  * build(deps): bump gatsby from 4.15.2 to 4.19.2 in /docs (#3046)
  * build(deps): bump gatsby-transformer-yaml from 4.13.0 to 4.19.0 in /docs (#3045)
  * build(deps): bump gatsby-plugin-offline from 5.17.0 to 5.19.0 in /docs (#3043)
  * build(deps): bump gatsby-plugin-emotion from 7.17.0 to 7.19.0 in /docs (#3047)
  * build(deps): bump gatsby-plugin-react-helmet from 5.17.0 to 5.19.0 in /docs (#3042)
  * build(deps): bump gatsby-plugin-sharp from 4.17.0 to 4.19.0 in /docs (#3044)
  * build(deps): bump gatsby-plugin-netlify from 4.3.1 to 5.0.1 in /docs (#3041)
  * build(deps): bump gatsby-transformer-sharp from 4.13.0 to 4.19.0 in /docs (#3040)
  * build(deps): bump github.com/daixiang0/gci from 0.5.0 to 0.6.0 (#3035)
  * docs(install): remove outdated info on source install (#3039)
  * dev: syntax highlight for all dockerfiles (#3038)
  * ifshort: deprecate linter (#3034)
  * nolint: drop allow-leading-space option and add "nolint:all" (#3002)
  * docs: Update documentation and assets (#3036)
* Wed Oct  5 2022 jkowalczyk@suse.com
- Update to version 1.47.2:
  * revive: ignore slow rules (#2999)
  * build(deps): bump terser from 5.12.0 to 5.14.2 in /docs (#2998)
  * docs: Update documentation and assets (#2996)
* Wed Oct  5 2022 jkowalczyk@suse.com
- Update to version 1.47.1:
  * Revert 'fix: generics (#2991)' (#2995)
  * fix: disable structcheck for go >= 1.18 (#2994)
  * build(deps): bump github.com/daixiang0/gci from 0.4.2 to 0.4.3 (#2992)
  * fix: generics (#2991)
  * gci: fix options display (#2989)
  * build(deps): bump github.com/sivchari/tenv from 1.6.0 to 1.7.0 (#2988)
  * gci: remove the use of stdin (#2984)
  * docs: Update documentation and assets (#2981)
* Wed Oct  5 2022 jkowalczyk@suse.com
- Update to version 1.47.0:
  * Add linter `asasalint` to lint pass []any as any (#2968)
  * build(deps): bump github.com/daixiang0/gci from 0.4.1 to 0.4.2 (#2979)
  * dev: use directives instead of comments for tests (#2978)
  * staticcheck: fix generics (#2976)
  * dev: remove kortschak from generated team (#2974)
  * build(deps): bump github.com/daixiang0/gci from 0.4.0 to 0.4.1 (#2973)
  * dev: change err to nil (#2971)
  * build(deps): bump moment from 2.29.2 to 2.29.4 in /.github/contributors (#2966)
  * build(deps): bump moment from 2.29.2 to 2.29.4 in /docs (#2967)
  * build(deps): bump github.com/daixiang0/gci from 0.3.4 to 0.4.0 (#2965)
  * build(deps): bump github.com/uudashr/gocognit from 1.0.5 to 1.0.6 (#2962)
  * build(deps): bump parse-url from 6.0.0 to 6.0.2 in /docs (#2961)
  * build(deps): bump github.com/stretchr/testify from 1.7.5 to 1.8.0 (#2957)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.5 to 3.22.6 (#2959)
  * build(deps): bump github.com/hashicorp/go-version from 1.5.0 to 1.6.0 (#2958)
  * build(deps): bump react from 18.1.0 to 18.2.0 in /docs (#2953)
  * build(deps): bump gatsby-plugin-google-analytics from 4.13.0 to 4.17.0 in /docs (#2952)
  * build(deps): bump gatsby-plugin-sharp from 4.13.0 to 4.17.0 in /docs (#2951)
  * build(deps): bump gatsby-remark-copy-linked-files from 5.13.0 to 5.17.0 in /docs (#2950)
  * build(deps): bump postcss from 8.4.13 to 8.4.14 in /docs (#2949)
  * add nosnakecase lint (#2828)
  * build(deps): bump github.com/maratori/testpackage from 1.0.1 to 1.1.0 (#2945)
  * build(deps): bump gitlab.com/bosi/decorder from 0.2.1 to 0.2.2 (#2943)
  * build(deps): bump github.com/stretchr/testify from 1.7.4 to 1.7.5 (#2942)
  * build(deps): bump github.com/firefart/nonamedreturns from 1.0.2 to 1.0.4 (#2944)
  * build(deps): bump gatsby-plugin-catch-links from 4.13.0 to 4.17.0 in /docs (#2938)
  * build(deps): bump gatsby-plugin-offline from 5.13.0 to 5.17.0 in /docs (#2937)
  * build(deps): bump gatsby-plugin-react-helmet from 5.13.0 to 5.17.0 in /docs (#2939)
  * build(deps): bump gatsby-plugin-emotion from 7.13.0 to 7.17.0 in /docs (#2936)
  * build(deps): bump react-live from 3.1.0 to 3.1.1 in /docs (#2935)
  * build(deps): bump github.com/stretchr/testify from 1.7.2 to 1.7.4 (#2934)
  * build(deps): bump github.com/spf13/cobra from 1.4.0 to 1.5.0 (#2933)
  * chore: remove reviewers from dependabot configuration (#2932)
  * build(deps): bump github.com/fzipp/gocyclo from 0.5.1 to 0.6.0 (#2926)
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.6.1 to 2.6.2 (#2928)
  * build(deps): bump github.com/sivchari/tenv from 1.5.0 to 1.6.0 (#2927)
  * build(deps): bump github.com/securego/gosec/v2 from 2.11.0 to 2.12.0 (#2925)
  * build(deps): bump github.com/firefart/nonamedreturns from 1.0.1 to 1.0.2 (#2929)
  * depguard: adjust phrasing (#2921)
  * config: spread go version on linter's configurations (#2913)
  * build(deps): bump github.com/kunwardeep/paralleltest from 1.0.4 to 1.0.6 (#2918)
  * build(deps): bump github.com/GaijinEntertainment/go-exhaustruct/v2 from 2.1.0 to 2.2.0 (#2916)
  * build(deps): bump github.com/stretchr/testify from 1.7.1 to 1.7.2 (#2917)
  * gosec: allow `global` config (#2880)
  * docs(gomnd): fix typo (#2909)
  * docs: add thanks page (#2893)
  * docs: have a clear explanation about the staticcheck integration. (#2894)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.4 to 3.22.5 (#2908)
  * build(deps): bump github.com/kunwardeep/paralleltest from 1.0.3 to 1.0.4 (#2907)
  * build(deps): bump github.com/nishanths/exhaustive from 0.7.11 to 0.8.1 (#2906)
  * build(deps): bump devcert from 1.2.0 to 1.2.1 in /docs (#2905)
  * dev: preallocate some slices and maps (#2902)
  * build(deps): bump gatsby-plugin-mdx from 3.13.0 to 3.15.2 in /docs (#2904)
  * build(deps): bump gatsby-plugin-manifest from 4.13.0 to 4.15.1 in /docs (#2899)
  * build(deps): bump gatsby-remark-images from 6.13.0 to 6.15.1 in /docs (#2898)
  * build(deps): bump gatsby from 4.13.1 to 4.15.2 in /docs (#2895)
  * build(deps): bump prism-react-renderer from 1.3.1 to 1.3.3 in /docs (#2896)
  * build(deps): bump gatsby-remark-autolink-headers from 5.13.0 to 5.15.1 in /docs (#2897)
  * build(deps): bump sharp from 0.30.3 to 0.30.6 in /docs (#2900)
  * gci: fix issues and re-enable autofix (#2892)
  * docs(gocritic): add `enable` and `disable` ruleguard settings (#2885)
  * docs(depguard): add `ignore-file-rules` (#2884)
  * docs(gosec): add configs for all existing rules (#2886)
  * docs(thelper): add `fuzz` config and description (#2887)
  * docs(govet): add settings for `shadow` and `unusedresult` (#2890)
  * docs(linters): add defaults (#2891)
  * build(deps): bump github.com/spf13/viper from 1.11.0 to 1.12.0 (#2889)
  * build(deps): bump github.com/Antonboom/errname from 0.1.6 to 0.1.7 (#2888)
  * fix: codeQL scanning (#2882)
  * build(deps): bump goreleaser/goreleaser-action from 2 to 3 (#2876)
  * build(deps): bump honnef.co/go/tools from 0.3.1 to 0.3.2 (#2870)
  * bump golang.org/x/tools to HEAD (#2875)
  * build(deps): bump github.com/kisielk/errcheck from 1.6.0 to 1.6.1 (#2871)
  * build(deps): bump github.com/quasilyte/go-ruleguard/dsl from 0.3.19 to 0.3.21 (#2874)
  * build(deps): bump github.com/kulti/thelper from 0.6.2 to 0.6.3 (#2872)
  * build(deps): bump github.com/hashicorp/go-version from 1.4.0 to 1.5.0 (#2873)
  * docs: fix typo (#2867)
  * chore: spelling and grammar fixes (#2865)
  * docs: Update documentation and assets (#2860)
* Wed May 18 2022 Jeff Kowalczyk <jkowalczyk@suse.com>
- Remove defines and ldflags -X entries for release_version and
  release_short_commit. This information is embedded in binaries
  with go1.18+ and available via go version -m binaryname. Using
  RPM Version: field allows OBS Source Service tar_scm to update
  Version from a single entry in _service.
* Wed May 18 2022 Jeff Kowalczyk <jkowalczyk@suse.com>
- Switch to xz compression per previous packaging source comments
  * obs-service-go_modules >= 0.4.1 supports xz compression
* Wed May 18 2022 jkowalczyk@suse.com
- Update to version 1.46.2:
  * build(deps): bump golangci/golangci-lint-action from 3.1.0 to 3.2.0 (#2858)
  * thelper: allow to disable one option (#2854)
  * bump github.com/polyfloyd/go-errorlint to v1.0.0 (#2855)
  * docs: rename .golangci.example.yml to .golangci.reference.yml (#2857)
  * bump github.com/lufeee/execinquery from v1.2.0 to v1.2.1 (#2853)
  * docs: Update documentation and assets (#2846)
* Wed May 18 2022 jkowalczyk@suse.com
- Update to version 1.46.1:
  * bump github.com/lufeee/execinquery from v1.0.0 to v1.2.0 (#2845)
  * fix: fix typo for errchkjson (#2842)
  * docs: add missing linters (#2841)
  * build(deps): bump docker/setup-qemu-action from 1 to 2 (#2837)
  * build(deps): bump docker/build-push-action from 2 to 3 (#2838)
  * build(deps): bump docker/setup-buildx-action from 1 to 2 (#2836)
  * docs: Update documentation and assets (#2833)
* Wed May 18 2022 jkowalczyk@suse.com
- Update to version 1.46.0:
  * docs: update "Shell Completion" instruction on Linux (#2829)
  * build(deps): bump gatsby-plugin-robots-txt from 1.7.0 to 1.7.1 in /docs (#2820)
  * build(deps): bump react from 18.0.0 to 18.1.0 in /docs (#2822)
  * build(deps): bump gatsby-plugin-catch-links in /docs (#2818)
  * build(deps): bump postcss from 8.4.12 to 8.4.13 in /docs (#2819)
  * build(deps): bump react-dom from 18.0.0 to 18.1.0 in /docs (#2821)
  * build(deps): bump gatsby-plugin-emotion from 7.11.0 to 7.13.0 in /docs (#2817)
  * build(deps): bump gatsby-plugin-canonical-urls in /docs (#2816)
  * build(deps): bump gatsby-plugin-mdx from 3.11.1 to 3.13.0 in /docs (#2815)
  * build(deps): bump polished from 4.1.4 to 4.2.2 in /docs (#2810)
  * build(deps): bump gatsby-plugin-manifest from 4.11.1 to 4.13.0 in /docs (#2814)
  * build(deps): bump gatsby-remark-images from 6.11.1 to 6.13.0 in /docs (#2813)
  * build(deps): bump gatsby-transformer-yaml from 4.11.0 to 4.13.0 in /docs (#2812)
  * build(deps): bump gatsby-plugin-offline from 5.11.1 to 5.13.0 in /docs (#2809)
  * build(deps): bump gatsby-plugin-react-helmet in /docs (#2811)
  * build(deps): bump react-live from 3.0.0 to 3.1.0 in /docs (#2808)
  * build(deps): bump @emotion/react from 11.8.2 to 11.9.0 in /docs (#2807)
  * build(deps): bump gatsby-plugin-netlify from 4.1.0 to 4.3.1 in /docs (#2806)
  * build(deps): bump gatsby-plugin-google-analytics in /docs (#2805)
  * build(deps): bump gatsby-transformer-remark in /docs (#2804)
  * build(deps): bump gatsby-remark-responsive-iframe in /docs (#2803)
  * build(deps): bump gatsby-plugin-sitemap from 5.11.1 to 5.13.0 in /docs (#2802)
  * build(deps): bump gatsby-transformer-sharp in /docs (#2798)
  * build(deps): bump gatsby from 4.11.1 to 4.13.1 in /docs (#2796)
  * build(deps): bump gatsby-remark-autolink-headers in /docs (#2801)
  * build(deps): bump gatsby-source-filesystem in /docs (#2800)
  * build(deps): bump gatsby-remark-copy-linked-files in /docs (#2797)
  * build(deps): bump gatsby-plugin-sharp from 4.11.1 to 4.13.0 in /docs (#2795)
  * build(deps): bump puppeteer from 13.5.2 to 13.7.0 in /docs (#2794)
  * build(deps): bump github.com/ldez/gomoddirectives from 0.2.2 to 0.2.3 (#2793)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.3 to 3.22.4 (#2792)
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.6.0 to 2.6.1 (#2791)
  * promlinter: bump to v0.2.0 (#2789)
  * feat: add `exhaustruct` linter (#2667)
  * build(deps): bump github/codeql-action from 1 to 2 (#2782)
  * build(deps): bump github.com/stbenjam/no-sprintf-host-port (#2781)
  * build(deps): bump honnef.co/go/tools from 0.3.0 to 0.3.1 (#2780)
  * nonamedreturns: bump from 1.0.0 to 1.0.1 (#2776)
  * Add nosprintfhostport linter (#2749)
  * unused: fix false-positive (#2772)
  * Add nonamedreturns linter (#2701)
  * build(deps): bump github.com/spf13/viper from 1.10.1 to 1.11.0 (#2770)
  * build(deps): bump actions/setup-go from 2 to 3 (#2763)
  * build(deps): bump moment from 2.25.3 to 2.29.2 in /.github/contributors (#2753)
  * build(deps): bump github.com/go-critic/go-critic from 0.6.2 to 0.6.3 (#2759)
  * build(deps): bump github.com/mgechev/revive from 1.2.0 to 1.2.1 (#2760)
  * build(deps): bump github.com/nishanths/predeclared from 0.2.1 to 0.2.2 (#2761)
  * build(deps): bump github.com/BurntSushi/toml from 1.0.0 to 1.1.0 (#2755)
  * build(deps): bump github.com/fzipp/gocyclo from 0.5.0 to 0.5.1 (#2756)
  * build(deps): bump github.com/Antonboom/nilnil from 0.1.0 to 0.1.1 (#2757)
  * build(deps): bump github.com/Antonboom/errname from 0.1.5 to 0.1.6 (#2758)
  * build(deps): bump moment from 2.29.1 to 2.29.2 in /docs (#2754)
  * bump github.com/kulti/thelper from 0.5.1 to 0.6.2 (#2742)
  * build(deps): bump react and react-dom in /docs (#2727)
  * dev: support build tags about go version in linter tests (#2744)
  * feat(log): enable override coloring based on CLICOLOR and CLICOLOR_FORCE (#2657)
  * staticcheck: re-enable for go1.18 (#2746)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.2 to 3.22.3 (#2740)
  * build(deps): bump github.com/mgechev/revive from 1.1.4 to 1.2.0 (#2741)
  * build(deps): bump github.com/sivchari/tenv from 1.4.7 to 1.5.0 (#2739)
  * dev: remove some TODO (#2743)
  * build(deps): bump honnef.co/go/tools from 0.2.2 to 0.3.0 (#2738)
  * build(deps): bump gatsby-plugin-google-analytics in /docs (#2736)
  * build(deps): bump @emotion/react from 11.8.1 to 11.8.2 in /docs (#2737)
  * build(deps): bump gatsby-plugin-sitemap from 5.9.0 to 5.11.1 in /docs (#2735)
  * build(deps): bump puppeteer from 13.1.3 to 13.5.2 in /docs (#2734)
  * build(deps): bump gatsby-transformer-remark in /docs (#2733)
  * build(deps): bump gatsby-plugin-manifest from 4.9.0 to 4.11.1 in /docs (#2732)
  * build(deps): bump postcss from 8.4.6 to 8.4.12 in /docs (#2731)
  * build(deps): bump gatsby-plugin-sharp from 4.9.0 to 4.11.1 in /docs (#2724)
  * build(deps): bump gatsby-remark-responsive-iframe in /docs (#2730)
  * build(deps): bump gatsby-plugin-canonical-urls in /docs (#2729)
  * build(deps): bump gatsby-plugin-react-helmet in /docs (#2728)
  * build(deps): bump gatsby-plugin-mdx from 3.9.0 to 3.11.1 in /docs (#2726)
  * build(deps): bump gatsby-plugin-emotion from 7.9.0 to 7.11.0 in /docs (#2725)
  * build(deps): bump gatsby-transformer-yaml from 4.7.0 to 4.11.0 in /docs (#2719)
  * build(deps): bump gatsby-remark-autolink-headers in /docs (#2722)
  * build(deps): bump gatsby from 4.9.0 to 4.11.1 in /docs (#2723)
  * build(deps): bump url-join from 4.0.1 to 5.0.0 in /docs (#2721)
  * build(deps): bump gatsby-remark-copy-linked-files in /docs (#2720)
  * build(deps): bump gatsby-source-filesystem from 4.7.0 to 4.11.1 in /docs (#2718)
  * build(deps): bump @emotion/styled from 11.6.0 to 11.8.1 in /docs (#2717)
  * build(deps): bump gatsby-plugin-offline from 5.6.0 to 5.11.1 in /docs (#2716)
  * build(deps): bump gatsby-plugin-catch-links in /docs (#2715)
  * build(deps): bump gatsby-transformer-sharp from 4.7.0 to 4.11.0 in /docs (#2714)
  * build(deps): bump gatsby-remark-images from 6.7.0 to 6.11.1 in /docs (#2713)
  * docs: update FAQ page. (#2705)
  * build(deps): bump github.com/securego/gosec/v2 from 2.10.0 to 2.11.0 (#2697)
  * build(deps): bump ansi-regex from 3.0.0 to 3.0.1 in /.github/peril (#2700)
  * bump deadcode to HEAD (#2704)
  * build(deps): bump github.com/fzipp/gocyclo from 0.4.0 to 0.5.0 (#2693)
  * bump varnamelen to v0.8.0 (#2703)
  * Add execinquery linter (#2677)
  * build(deps): bump peter-evans/create-pull-request from 3 to 4 (#2699)
  * build(deps): bump github.com/breml/bidichk from 0.2.2 to 0.2.3 (#2698)
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.5.0 to 2.6.0 (#2696)
  * build(deps): bump github.com/breml/errchkjson from 0.2.3 to 0.3.0 (#2695)
  * build(deps): bump github.com/quasilyte/go-ruleguard/dsl (#2691)
  * build(deps): bump mvdan.cc/gofumpt from 0.3.0 to 0.3.1 (#2694)
  * build(deps): bump minimist from 1.2.5 to 1.2.6 in /.github/contributors (#2685)
  * build(deps): bump minimist from 1.2.5 to 1.2.6 in /docs (#2688)
  * build(deps): bump minimist from 1.2.5 to 1.2.6 in /.github/peril (#2687)
  * build(deps): bump minimist from 1.2.5 to 1.2.6 in /tools (#2686)
  * bump varnamelen to v0.6.2 (#2684)
  * docs: Update documentation and assets (#2682)
* Sat Mar 26 2022 maciek.borzecki@gmail.com
- Update to version 1.45.2:
  * fix: help command (#2681)
  * feat: automatic Go version detection (#2669)
  * build(deps): bump actions/cache from 2.1.7 to 3 (#2674)
  * depguard: reduce requirements (#2672)
  * fix: disable structcheck with go1.18 (#2666)
  * docs: fix GitHub Releases Stats badge link. (#2665)
  * fix: update base images (#2661)
  * build(deps): bump github.com/stretchr/testify from 1.7.0 to 1.7.1 (#2660)
  * build(deps): bump github.com/hashicorp/go-version from 1.2.1 to 1.4.0 (#2659)
  * bump varnamelen to v0.6.1 (#2656)
  * docs: Update documentation and assets (#2655)
  * fix: completion for fish-shell
  * go1.18 support (#2438)
  * build(deps): bump github.com/spf13/cobra from 1.3.0 to 1.4.0 (#2646)
  * gofumpt: add module-path setting (#2644)
  * build(deps): bump actions/checkout from 2 to 3 (#2643)
  * build(deps): bump normalize-url from 4.5.0 to 4.5.1 in /docs (#2642)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.22.1 to 3.22.2 (#2641)
  * build(deps): bump github.com/daixiang0/gci from 0.3.1 to 0.3.2 (#2640)
  * build(deps): bump gatsby-plugin-manifest from 4.7.0 to 4.9.0 in /docs (#2635)
  * build(deps): bump @emotion/react from 11.7.1 to 11.8.1 in /docs (#2634)
  * build(deps): bump gatsby-plugin-sharp from 4.6.0 to 4.9.0 in /docs (#2636)
  * build(deps): bump gatsby-plugin-emotion from 7.7.0 to 7.9.0 in /docs (#2632)
  * build(deps): bump gatsby-plugin-mdx from 3.6.0 to 3.9.0 in /docs (#2629)
  * build(deps): bump gatsby from 4.6.2 to 4.9.0 in /docs (#2631)
  * build(deps): bump prism-react-renderer from 1.2.1 to 1.3.1 in /docs (#2630)
  * build(deps): bump gatsby-plugin-sitemap from 5.6.0 to 5.9.0 in /docs (#2633)
  * build(deps): bump actions/setup-node from 2 to 3 (#2628)
  * build(deps): bump golangci/golangci-lint-action from 2.5.2 to 3.1.0 (#2627)
  * build(deps): bump github.com/securego/gosec/v2 from 2.9.6 to 2.10.0 (#2624)
  * build(deps): bump github.com/ashanbrown/makezero from 1.1.0 to 1.1.1 (#2621)
  * build(deps): bump github.com/sivchari/containedctx from 1.0.1 to 1.0.2 (#2623)
  * build(deps): bump url-parse from 1.5.7 to 1.5.10 in /docs (#2625)
  * build(deps): bump mvdan.cc/gofumpt from 0.2.1 to 0.3.0 (#2622)
  * build(deps): bump mermaid from 8.8.0 to 8.14.0 in /docs (#2620)
  * build(deps): bump node-fetch in /.github/contributors (#2616)
  * Default to YAML when config file has no extension (#2618)
  * docs: improve linters page (#2617)
  * bump github.com/denis-tingaikin/go-header from 0.4.2 to 0.4.3 (#2614)
  * revive: fix default values (#2611)
  * errcheck: add an option to remove default exclusions (#2607)
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.4.0 to 2.5.0 (#2603)
  * docs: add forbidigo example that uses comments (#2599)
  * docs: add "back to the top" button (#2602)
  * bump github.com/daixiang0/gci to v0.3.1 (#2596)
  * build(deps): bump gatsby-plugin-emotion from 7.6.0 to 7.7.0 in /docs (#2585)
  * build(deps): bump gatsby-transformer-sharp from 4.6.0 to 4.7.0 in /docs (#2584)
  * docs: Update documentation and assets (#2594)
* Wed Feb 23 2022 maciek.borzecki@gmail.com
- Update to version 1.44.2:
  * build(deps): bump url-parse from 1.5.1 to 1.5.7 in /docs (#2590)
  * build(deps): bump gatsby-plugin-manifest from 4.6.0 to 4.7.0 in /docs (#2586)
  * build(deps): bump gatsby-remark-images from 6.6.0 to 6.7.0 in /docs (#2582)
  * build(deps): bump gatsby-transformer-yaml from 4.6.0 to 4.7.0 in /docs (#2583)
  * bump github.com/daixiang0/gci to HEAD (#2593)
  * gci: restore defaults for sections (#2589)
  * build(deps): bump github.com/ultraware/whitespace from 0.0.4 to 0.0.5 (#2580)
  * docs: add link to configuration in the linters list (#2587)
  * build(deps): bump gatsby-source-filesystem from 4.6.0 to 4.7.0 in /docs (#2581)
  * docs: Update documentation and assets (#2579)
  * gci: fix configuration naming (#2578)
  * bump github.com/mgechev/revive from v1.1.3 to v1.1.4 (#2576)
  * build(deps): bump github.com/breml/errchkjson from 0.2.2 to 0.2.3 (#2570)
  * build(deps): bump github.com/breml/bidichk from 0.2.1 to 0.2.2 (#2572)
  * build(deps): bump github.com/quasilyte/go-ruleguard/dsl (#2571)
  * build(deps): bump follow-redirects from 1.14.7 to 1.14.8 in /docs (#2567)
  * bump github.com/daixiang0/gci from 0.2.9 to 0.3.0 (#2532)
  * build(deps): bump ajv from 6.12.2 to 6.12.6 in /.github/peril (#2564)
  * docs(decorder): fix `disable-init-func-first-check: false` elaboration (#2560)
  * build(deps): bump github.com/quasilyte/go-ruleguard/dsl (#2556)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.12 to 3.22.1 (#2558)
  * build(deps): bump github.com/ldez/tagliatelle from 0.3.0 to 0.3.1 (#2557)
  * build(deps): bump github.com/breml/errchkjson from 0.2.1 to 0.2.2 (#2559)
  * build(deps): bump simple-get from 4.0.0 to 4.0.1 in /docs (#2554)
  * dev: upgrade to gatsby 4 (#2553)
  * build(deps): bump simple-get from 3.1.0 to 3.1.1 in /docs (#2552)
  * bump varnamelen from v0.5.0 to v0.6.0 (#2551)
  * build(deps): bump gatsby-remark-copy-linked-files in /docs (#2545)
  * build(deps): bump puppeteer from 13.0.1 to 13.1.3 in /docs (#2547)
  * build(deps): bump polished from 4.1.3 to 4.1.4 in /docs (#2548)
  * build(deps): bump prop-types from 15.8.0 to 15.8.1 in /docs (#2546)
  * build(deps): bump gatsby-plugin-sitemap from 5.4.0 to 5.6.0 in /docs (#2542)
  * build(deps): bump gatsby-plugin-offline from 5.4.0 to 5.6.0 in /docs (#2541)
  * build(deps): bump react-live from 2.3.0 to 2.4.1 in /docs (#2540)
  * build(deps): bump gatsby-plugin-google-analytics in /docs (#2539)
  * Revert "build(deps): bump github.com/sylvia7788/contextcheck from 1.0.4 to 1.0.5 (#2534)" (#2538)
  * build(deps): bump ssri from 6.0.1 to 6.0.2 in /docs (#2536)
  * build(deps): bump github.com/sylvia7788/contextcheck from 1.0.4 to 1.0.5 (#2534)
  * build(deps): bump ws from 6.2.1 to 6.2.2 in /docs (#2537)
  * build(deps): bump github.com/kulti/thelper from 0.5.0 to 0.5.1 (#2535)
  * fix debug output (#2531)
  * docs: fix misinterpreted XML tag in changelog (#2522)
  * docs: Update documentation and assets (#2521)
  * docs(revive): fix typo on the option `disabled`(#2520)
  * Add "grouper" linter (#2497)
  * build(deps): bump github.com/mgechev/revive from 1.1.2 to 1.1.3 (#2517)
  * build(deps): bump github.com/securego/gosec/v2 from 2.9.5 to 2.9.6 (#2516)
  * build(deps): bump github.com/quasilyte/go-ruleguard/dsl (#2519)
  * build(deps): bump github.com/tommy-muehle/go-mnd/v2 from 2.4.0 to 2.5.0 (#2518)
  * docs: improve configuration documentation (#2514)
  * forcetypeassert: bump to v0.1.0 (#2511)
  * asciicheck: bump to v0.1.1 (#2510)
  * ineffassign: bump to HEAD (#2509)
  * bodyclose: bump to HEAD (#2508)
  * errorlint: bump to HEAD (#2507)
  * unparam: bump to HEAD (#2506)
  * docs: improve page about false-postive (#2502)
  * docs: improve configuration file content (#2501)
  * fix: importas no-extra-aliases (#2503)
  * docs: split configuration page into multiple sections (#2484)
  * docs: improve linters settings section (#2499)
  * bump github.com/yeya24/promlinter from v0.1.0 to HEAD (#2500)
  * importas: new option `no-extra-aliases` (#2494)
  * add containedctx linter (#2382)
  * gomnd: new configuration (#2498)
  * varnamelen: explicit default values (#2496)
  * Add maintidx linter (#2435)
  * dev: rename `rowserrcheck` linter file to match linter name. (#2495)
  * build(deps): bump github.com/BurntSushi/toml from 0.4.1 to 1.0.0 (#2491)
  * build(deps): bump github.com/breml/errchkjson from 0.2.0 to 0.2.1 (#2493)
  * build(deps): bump github.com/kulti/thelper from 0.4.0 to 0.5.0 (#2492)
  * Bump makezero to v1.1.0 (#2490)
  * Bump github.com/ashanbrown/forbidigo from 1.2.0 to 1.3.0 (#2487)
  * Return error if any linter fails to run (#2471)
  * godot: add period option (#2483)
  * exhaustive: drop deprecated/unused settings (#2482)
  * docs: updates usage settings for `go-mnd` (#2476)
  * build(deps): bump gitlab.com/bosi/decorder from 0.2.0 to 0.2.1 (#2473)
  * build(deps): bump github.com/go-critic/go-critic from 0.6.1 to 0.6.2 (#2474)
  * build(deps): bump github.com/quasilyte/go-ruleguard/dsl (#2472)
  * dev: add printers unit tests. (#2461)
  * depguard: updates configuration (#2467)
  * pkg/result/processors: compile nolint regexp only once (#2463)
  * Print error text in <failure> tag content for more readable junit report (#2460)
  * Add decorder linter (#2453)
  * Add support for multiple outputs (#2386)
  * docs: more revive examples (#2459)
  * dev: improve and clean fix_test (#2457)
  * doc: improve revive documentation (#2458)
  * build(deps): bump github.com/ldez/tagliatelle from 0.2.0 to 0.3.0 (#2454)
  * build(deps): bump github.com/quasilyte/go-ruleguard/dsl (#2455)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.11 to 3.21.12 (#2456)
  * gocritic: support autofix (#2450)
  * build(deps): bump gatsby-plugin-offline from 5.3.0 to 5.4.0 in /docs (#2448)
  * build(deps): bump gatsby-plugin-sitemap from 5.3.0 to 5.4.0 in /docs (#2447)
  * build(deps): bump prop-types from 15.7.2 to 15.8.0 in /docs (#2444)
  * build(deps): bump @emotion/react from 11.7.0 to 11.7.1 in /docs (#2446)
  * build(deps): bump gatsby-plugin-google-analytics in /docs (#2443)
  * build(deps): bump puppeteer from 12.0.1 to 13.0.1 in /docs (#2442)
  * build(deps): bump gatsby-remark-copy-linked-files in /docs (#2441)
  * fix: update uname_os from shlib in install.sh (#1944) (#2388)
  * dev: sorting linters by alphabet (ascending order) (#2437)
  * build(deps): bump github.com/esimonov/ifshort from 1.0.3 to 1.0.4 (#2436)
  * build(deps): bump github.com/spf13/cobra from 1.2.1 to 1.3.0 (#2426)
  * build(deps): bump github.com/spf13/viper from 1.10.0 to 1.10.1 (#2424)
  * build(deps): bump mvdan.cc/gofumpt from 0.2.0 to 0.2.1 (#2427)
  * build(deps): bump github.com/fzipp/gocyclo from 0.3.1 to 0.4.0 (#2425)
  * revive: fix enableAllRules (#2380)
  * build(deps): bump github.com/spf13/viper from 1.9.0 to 1.10.0 (#2412)
  * build(deps): bump github.com/securego/gosec/v2 from 2.9.3 to 2.9.5 (#2413)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.10 to 3.21.11 (#2405)
  * build(deps): bump @emotion/styled from 11.3.0 to 11.6.0 in /docs (#2397)
  * build(deps): bump gatsby-plugin-google-analytics in /docs (#2398)
  * build(deps): bump gatsby-remark-copy-linked-files in /docs (#2396)
  * build(deps): bump puppeteer from 10.4.0 to 12.0.1 in /docs (#2392)
  * build(deps): bump gatsby-plugin-sitemap from 5.0.0 to 5.3.0 in /docs (#2391)
  * build(deps): bump gatsby-plugin-offline from 5.0.0 to 5.3.0 in /docs (#2390)
  * build(deps): bump @emotion/react from 11.5.0 to 11.7.0 in /docs (#2389)
  * build(deps): bump github.com/securego/gosec/v2 from 2.9.2 to 2.9.3 (#2385)
  * build(deps): bump github.com/mattn/go-colorable from 0.1.11 to 0.1.12 (#2384)
  * build(deps): bump actions/cache from 2.1.6 to 2.1.7 (#2383)
  * wrapcheck: update configuration to include ignoreSignRegexps (#2379)
  * Add errchkjson linter (#2362)
  * build(deps): bump github.com/nishanths/exhaustive from 0.6.0 to 0.7.11 (#2371)
  * build(deps): bump mvdan.cc/gofumpt from 0.1.1 to 0.2.0 (#2373)
  * build(deps): bump github.com/securego/gosec/v2 from 2.9.1 to 2.9.2 (#2372)
  * build(deps): bump honnef.co/go/tools from 0.2.1 to 0.2.2 (#2370)
  * bump varnamelen from v0.4.0 to v0.5.0 (#2369)
  * dev: clean up and used iota for exit codes (#2366)
  * dev: reused exit codes (#2364)
  * docs: fix wrong default value in comment (#2360)
  * Show deprecated mark in the CLI linters help (#2350)
  * Ensure that the Issues key in JSON format is a list (#2358)
  * fix: reduce flaky in the CI and clean the .golangci.yml of the project (#2359)
  * docs: fix grammar issues in comments (#2352)
  * build(deps): bump github.com/nishanths/exhaustive from 0.3.6 to 0.6.0 (#2353)
  * build(deps): bump github.com/breml/bidichk from 0.2.0 to 0.2.1 (#2354)
  * docs: fix a typo and a syntax error in architecture.mdx (#2351)
  * bump bidichk from v0.1.1 to v0.2.0
  * bump varnamelen to v0.4.0 (#2348)
  * exhaustive: upgrade to v0.3.6; add new flags and deprecate old ones (#2344)
  * docs: Update documentation and assets (#2342)
* Tue Nov 16 2021 maciek.borzecki@gmail.com
- Update to version 1.43.0:
  * Add github.com/breml/bidichk linter (#2330)
  * docs: add documentation for go-critic and ruleguard settings (#2304)
  * gocritic: add support for variable substitution in ruleguard path settings (#2308)
  * docs: change Github to GitHub in comments and docs (#2341)
  * Refactor: preallocate slices (#2340)
  * fix: don't hide enable-all option (#2338)
  * codeql: Remove unneeded steps (#2336)
  * fix: Add missing space in "disabled by config" warning (#2310)
  * build(deps): bump gatsby-plugin-robots-txt in /docs (#2332)
  * build(deps): bump gatsby-remark-copy-linked-files in /docs (#2335)
  * build(deps): bump @emotion/react from 11.4.1 to 11.5.0 in /docs (#2331)
  * build(deps): bump react-icons from 4.2.0 to 4.3.1 in /docs (#2334)
  * build(deps): bump gatsby-plugin-google-analytics in /docs (#2321)
  * build(deps): bump react-headroom from 3.1.1 to 3.2.0 in /docs (#2333)
  * build(deps): bump gatsby-plugin-sitemap from 4.10.0 to 5.0.0 in /docs (#2320)
  * docs: clarify nolintlint.allow-unused (#2319)
  * build(deps): bump github.com/nakabonne/nestif from 0.3.0 to 0.3.1 (#2325)
  * build(deps): bump github.com/jingyugao/rowserrcheck from 1.1.0 to 1.1.1 (#2326)
  * build(deps): bump gatsby-plugin-react-svg from 3.0.1 to 3.1.0 in /docs (#2323)
  * build(deps): bump gatsby-plugin-offline from 4.14.0 to 5.0.0 in /docs (#2322)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.9 to 3.21.10 (#2327)
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.3.1 to 2.4.0 (#2324)
  * dev: replace ioutil with io and os (#2318)
  * Bump gochecknoglobals to v0.1.0 (#2317)
  * gosec: filter issues according to the severity and confidence (#2295)
  * add varnamelen linter (#2240)
  * errcheck: empty selector name. (#2309)
  * Add code comments to document source code (#2306)
  * build(deps): bump github.com/esimonov/ifshort from 1.0.2 to 1.0.3 (#2303)
  * build(deps): bump github.com/go-critic/go-critic from 0.5.6 to 0.6.0 (#2041)
  * build(deps): bump github.com/securego/gosec/v2 from 2.8.1 to 2.9.1 (#2299)
  * build(deps): bump github.com/charithe/durationcheck from 0.0.8 to 0.0.9 (#2289)
  * feat: add contextcheck linter (#2216)
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.3.0 to 2.3.1 (#2278)
  * build(deps): bump github.com/mattn/go-colorable from 0.1.10 to 0.1.11 (#2277)
  * build(deps): bump github.com/mgechev/revive from 1.1.1 to 1.1.2 (#2276)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.8 to 3.21.9 (#2275)
  * build(deps): bump gatsby-plugin-sitemap from 4.9.0 to 4.10.0 in /docs (#2271)
  * build(deps): bump gatsby-plugin-google-analytics in /docs (#2272)
  * build(deps): bump gatsby-plugin-offline from 4.13.0 to 4.14.0 in /docs (#2270)
  * build(deps): bump puppeteer from 10.2.0 to 10.4.0 in /docs (#2266)
  * build(deps): bump gatsby-plugin-mdx from 2.13.0 to 2.14.0 in /docs (#2267)
  * build(deps): bump gatsby-remark-copy-linked-files in /docs (#2265)
  * build(deps): bump gatsby-plugin-robots-txt from 1.6.9 to 1.6.10 in /docs (#2269)
  * new-from-rev: add support for finding issues in entire files in a diff (#2264)
  * fix: go.sum (#2262)
  * build(deps): bump github.com/mattn/go-colorable from 0.1.9 to 0.1.10 (#2260)
  * build(deps): bump github.com/fatih/color from 1.12.0 to 1.13.0 (#2259)
  * Add tenv linter (#2221)
  * build(deps): bump github.com/mattn/go-colorable from 0.1.8 to 0.1.9 (#2252)
  * build(deps): bump github.com/valyala/quicktemplate from 1.6.3 to 1.7.0 (#2250)
  * build(deps): bump golang.org/x/tools from 0.1.5 to 0.1.6 (#2245)
  * build(deps): bump github.com/Antonboom/errname from 0.1.4 to 0.1.5 (#2249)
  * build(deps): bump github.com/tetafro/godot from 1.4.10 to 1.4.11 (#2248)
  * build(deps): bump github.com/kunwardeep/paralleltest from 1.0.2 to 1.0.3 (#2244)
  * build(deps): bump tmpl from 1.0.4 to 1.0.5 in /.github/peril (#2247)
  * build(deps): bump github.com/spf13/viper from 1.8.1 to 1.9.0 (#2243)
  * build(deps): bump github.com/butuzov/ireturn from 0.1.0 to 0.1.1 (#2246)
  * nlreturn: add block-size option (#2237)
  * Add nilnil linter (#2236)
  * new-linter: ireturn (checks for function return type) (#2219)
  * Update index.mdx (#2230)
  * build(deps): bump github.com/tetafro/godot from 1.4.9 to 1.4.10 (#2226)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.7 to 3.21.8 (#2225)
  * docs: Update documentation and assets (#2224)
* Fri Oct  8 2021 maciek.borzecki@gmail.com
- Update to version 1.42.1:
  * gci: Parse the settings more similarly to the cli (#2217)
  * errcheck: update to HEAD (#2213)
  * build(deps): bump gatsby-plugin-mdx from 2.10.1 to 2.13.0 in /docs (#2210)
  * build(deps): bump puppeteer from 10.1.0 to 10.2.0 in /docs (#2211)
  * build(deps): bump gatsby-plugin-google-analytics in /docs (#2202)
  * build(deps): bump gatsby-remark-copy-linked-files in /docs (#2208)
  * build(deps): bump gatsby-plugin-sitemap from 4.6.0 to 4.9.0 in /docs (#2209)
  * build(deps): bump gatsby-plugin-robots-txt from 1.6.8 to 1.6.9 in /docs (#2206)
  * build(deps): bump react-live from 2.2.3 to 2.3.0 in /docs (#2207)
  * build(deps): bump gatsby-plugin-offline from 4.10.0 to 4.13.0 in /docs (#2203)
  * build(deps): bump @emotion/react from 11.4.0 to 11.4.1 in /docs (#2205)
  * build(deps): bump github.com/mgechev/revive from 1.1.0 to 1.1.1 (#2201)
  * build(deps): bump github.com/tetafro/godot from 1.4.8 to 1.4.9 (#2200)
  * build(deps): bump github.com/Antonboom/errname from 0.1.3 to 0.1.4 (#2192)
  * go-critic: fix invalid type conversions. (#2186)
  * Build docker images with go1.17 (#2188)
  * docs: fix link to Spacemacs (#2187)
  * Update Go versions used by the CI (#2183)
  * docs: Update documentation and assets (#2182)
  * Bump staticcheck to 2021.1.1 (v0.2.1) (#2179)
  * build(deps): bump github.com/mgechev/revive from 1.0.9 to 1.1.0 (#2174)
  * build(deps): bump path-parse from 1.0.6 to 1.0.7 in /.github/peril (#2169)
  * build(deps): bump path-parse from 1.0.6 to 1.0.7 in /tools (#2166)
  * dev: update feature_request.yml (#2168)
  * build(deps): bump github.com/BurntSushi/toml from 0.3.1 to 0.4.1 (#2165)
  * docs: suggest golangci-lint help linters (#2117)
  * Add errname linter (#2129)
  * build(deps): bump github.com/ryancurrah/gomodguard from 1.2.2 to 1.2.3 (#2155)
  * Revert "add nilassign linter" (#2154)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.6 to 3.21.7 (#2153)
  * deps: Update Wrapcheck to v2.3.0 (#2145)
  * build(deps): bump gatsby-remark-copy-linked-files in /docs (#2151)
  * build(deps): bump gatsby-plugin-sharp from 3.8.0 to 3.10.2 in /docs (#2149)
  * build(deps): bump gatsby-plugin-offline from 4.8.0 to 4.10.0 in /docs (#2152)
  * build(deps): bump gatsby-plugin-mdx from 2.8.0 to 2.10.1 in /docs (#2150)
  * build(deps): bump gatsby-plugin-sitemap from 4.4.0 to 4.6.0 in /docs (#2148)
  * build(deps): bump gatsby-plugin-google-analytics in /docs (#2147)
  * add nilassign linter (#2131)
  * docs: improve goconst documentation. (#2128)
  * build(deps): bump golang.org/x/tools from 0.1.4 to 0.1.5 (#2124)
  * build(deps): bump github.com/ldez/gomoddirectives from 0.2.1 to 0.2.2 (#2125)
  * build(deps): bump github.com/uudashr/gocognit from 1.0.1 to 1.0.5 (#2122)
  * build(deps): bump github.com/tetafro/godot from 1.4.7 to 1.4.8 (#2123)
  * errcheck: allow exclude config without extra file (#2110)
  * build(deps): bump github.com/nishanths/exhaustive from 0.1.0 to 0.2.3 (#2112)
  * build(deps): bump github.com/mgechev/revive from 1.0.8 to 1.0.9 (#2113)
  * docs: Improve goimports description (#2109)
  * cleanup: Remove completion subcommand (#2107)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.5 to 3.21.6 (#2106)
  * build(deps): bump github.com/spf13/cobra from 1.1.3 to 1.2.1 (#2105)
  * build(deps): bump gatsby-plugin-mdx from 2.6.0 to 2.8.0 in /docs (#2102)
  * build(deps): bump gatsby-plugin-robots-txt from 1.6.2 to 1.6.8 in /docs (#2101)
  * build(deps): bump gatsby-plugin-netlify-cache in /docs (#2103)
  * build(deps): bump gatsby-plugin-sitemap from 2.12.0 to 4.4.0 in /docs (#2094)
  * build(deps): bump react-dom from 16.14.0 to 17.0.2 in /docs (#2100)
  * build(deps): bump gatsby-remark-copy-linked-files in /docs (#2098)
  * build(deps): bump puppeteer from 10.0.0 to 10.1.0 in /docs (#2096)
  * build(deps): bump gatsby-plugin-google-analytics in /docs (#2095)
  * build(deps): bump gatsby-plugin-sharp from 2.14.4 to 3.8.0 in /docs (#2092)
  * build(deps): bump gatsby-plugin-offline from 3.10.2 to 4.8.0 in /docs (#2091)
  * docs: not show the number of linters (#2089)
  * build(deps): bump github.com/daixiang0/gci from 0.2.8 to 0.2.9 (#2085)
  * build(deps): bump github.com/mgechev/revive from 1.0.7 to 1.0.8 (#2086)
  * build(deps): bump github.com/gofrs/flock from 0.8.0 to 0.8.1 (#2083)
  * build(deps): bump github.com/spf13/viper from 1.8.0 to 1.8.1 (#2082)
  * build(deps): bump golang.org/x/tools from 0.1.3 to 0.1.4 (#2084)
  * dev: fix interface implement check for "SkipDirs" (#2078)
  * build(deps): bump color-string from 1.5.3 to 1.5.5 in /tools (#2081)
  * Support RISV64 (#2080)
  * docs: convert issue templates to issue forms. (#2077)
  * gofumpt: Add lang-version option (#2069)
  * revive: add enable-all-rules. (#2075)
  * build(deps): bump github.com/spf13/viper from 1.7.1 to 1.8.0 (#2072)
  * build(deps): bump github.com/tomarrell/wrapcheck/v2 from 2.1.0 to 2.2.0 (#2071)
  * build(deps): bump github.com/securego/gosec/v2 from 2.8.0 to 2.8.1 (#2073)
  * docs: Update documentation and assets (#2066)
  * revive: fix exclude comment rule for const block. (#2064)
  * Bump github.com/ryancurrah/gomodguard from 1.2.1 to 1.2.2 (#2065)
  * docs: update for v1.41.0 (#2062)
  * revive: allow to disable rule (#2055)
  * build(deps): bump github.com/charithe/durationcheck from 0.0.7 to 0.0.8 (#2052)
  * build(deps): bump golang.org/x/tools from 0.1.2 to 0.1.3 (#2053)
  * build(deps): bump ws from 5.2.2 to 5.2.3 in /.github/peril (#2045)
  * Bump github.com/jgautheron/goconst from 0.5.6 to 0.5.7(#2044)
  * output: generate HTML report (#2043)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.4 to 3.21.5 (#2042)
  * doc: add all integrations to docs introduction page (#2040)
  * doc: Un-deprecate enable-all option. (#2039)
  * build(deps): bump gatsby-plugin-robots-txt from 1.5.1 to 1.6.2 in /docs (#2035)
  * build(deps): bump gatsby-plugin-mdx from 2.2.0 to 2.6.0 in /docs (#2036)
  * build(deps): bump prism-react-renderer from 1.2.0 to 1.2.1 in /docs (#2037)
  * build(deps): bump gatsby from 2.32.11 to 2.32.13 in /docs (#2034)
  * build(deps): bump react from 16.14.0 to 17.0.2 in /docs (#2033)
  * build(deps): bump @emotion/react from 11.1.5 to 11.4.0 in /docs (#2029)
  * build(deps): bump puppeteer from 8.0.0 to 10.0.0 in /docs (#2032)
  * build(deps): bump gatsby-plugin-react-svg from 3.0.0 to 3.0.1 in /docs (#2031)
  * build(deps): bump gatsby-plugin-sharp from 2.14.3 to 2.14.4 in /docs (#2030)
  * build(deps): bump polished from 4.1.1 to 4.1.3 in /docs (#2028)
  * build(deps): bump github.com/tommy-muehle/go-mnd/v2 from 2.3.2 to 2.4.0 (#2024)
  * build(deps): bump github.com/mgechev/revive from 1.0.6 to 1.0.7 (#2027)
  * build(deps): bump github.com/securego/gosec/v2 from 2.7.0 to 2.8.0 (#2025)
  * nolintlint: fix false positive. (#2013)
  * build(deps): bump actions/cache from 2.1.5 to 2.1.6 (#2023)
  * build(deps): bump honnef.co/go/tools from v0.1.4 to v0.2.0 (#2019)
  * Update wastedassign to v2.0.6 (#2020)
  * gomodguard: fix problem where duplicate issues were being reported (#2018)
  * staticcheck: configuration for `staticcheck`, `gosimple`, `stylecheck` (#2017)
  * revive: fix excludes (#2005)
  * Update godot to 1.4.7 (#2010)
  * Update makezero to HEAD (#2006)
  * revive: improve 'exported' rule output. (#1994)
  * Update errorlint to HEAD (#1996)
  * Update rowserrcheck to v1.1.0 (#1997)
  * revive: fix add-constant rule support. (#2003)
  * docs: fix pattern of forbidigo in example config yaml  (#2000)
  * docs: improve linters page (#1995)
  * build(deps): bump github.com/charithe/durationcheck from 0.0.6 to 0.0.7 (#1990)
  * build(deps): bump github.com/fatih/color from 1.10.0 to 1.11.0 (#1992)
  * build(deps): bump github.com/ashanbrown/forbidigo from 1.1.0 to 1.2.0 (#1991)
  * docs: exhaustivestruct example explanation (#1985)
  * docs: update for v1.40.1 (#1983)
  * runner: non-zero exit code when a linter produces a panic (#1979)
  * govet: fix sigchanyzer (#1975)
  * doc: fix example config yaml identation (#1976)
  * docs: fix typo (#1971)
  * build(deps): bump lodash from 4.17.20 to 4.17.21 in /.github/peril (#1967)
  * golint: deprecation (#1965)
  * build(deps): bump hosted-git-info from 2.8.8 to 2.8.9 in /.github/peril (#1966)
  * build(deps): bump hosted-git-info from 2.7.1 to 2.8.9 in /tools (#1968)
  * build(deps): bump lodash from 4.17.19 to 4.17.21 in /tools (#1964)
  * docs: update for v1.40.0 (#1963)
  * importas: allow repeated aliases (#1960)
  * importas: add message if settings contain no aliases (#1956)
  * build(deps): bump emotion-theming from 10.0.27 to 11.0.0 in /docs . (#1623)
  * Bump wastedassign to v1.0.0 (#1955)
  * build(deps): bump honnef.co/go/tools from 0.1.3 to 0.1.4 (#1952)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.3 to 3.21.4 (#1951)
  * Update importas to HEAD (#1934)
  * Update errorlint to HEAD (#1933)
  * revive: convert hard coded excludes into default exclude patterns (#1938)
  * govet: Update vet passes (#1950)
  * build(deps): bump gatsby-remark-embedder from 4.1.0 to 4.2.0 in /docs (#1948)
  * build(deps): bump gatsby-transformer-sharp in /docs (#1949)
  * update go-critic to v0.5.6 (#1925)
  * feat: set the minimum Go version to go1.15 (#1926)
  * Update Wrapcheck to v2, add configuration (#1947)
  * staticcheck: configurable Go version. (#1946)
  * build(deps): bump github.com/tetafro/godot from 1.4.5 to 1.4.6 (#1935)
  * gosec: add configuration (#1930)
  * dev: cleanup config package (#1929)
  * Update wrapcheck to v1.2.0 (#1927)
  * Update wsl to 3.3.0, sort config in example config (#1922)
  * fix: comma in exclude pattern leads to unexpected results (#1917)
  * build(deps): bump github.com/tommy-muehle/go-mnd/v2 from 2.3.1 to 2.3.2 (#1919)
  * build(deps): bump actions/cache from v2.1.4 to v2.1.5 (#1918)
  * dev: clean configuration, documentation, and code (#1911)
  * Add tagliatelle linter (#1906)
  * build(deps): bump github.com/mgechev/revive from 1.0.5 to 1.0.6 (#1908)
  * build(deps): bump github.com/tetafro/godot from 1.4.4 to 1.4.5 (#1907)
  * fix release stats badge (#1901)
  * Bump importas to HEAD (#1899)
  * build(deps): bump github.com/tomarrell/wrapcheck from 1.0.0 to 1.1.0 (#1891)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.2 to 3.21.3 (#1890)
  * build(deps): bump golangci/golangci-lint-action from v2.5.1 to v2.5.2 (#1889)
  * typecheck: improve error stack parsing. (#1886)
  * build(deps): bump react-headroom from 3.1.0 to 3.1.1 in /docs (#1883)
  * build(deps): bump gatsby-plugin-netlify from 2.11.0 to 2.11.1 in /docs (#1882)
  * build(deps): bump gatsby from 2.32.8 to 2.32.11 in /docs (#1881)
  * build(deps): bump gatsby-plugin-mdx from 1.10.1 to 2.2.0 in /docs (#1880)
  * build(deps): bump y18n from 4.0.0 to 4.0.1 in /.github/peril (#1879)
  * Add promlinter to lint metrics name (#1265)
  * build(deps): bump github.com/hashicorp/go-multierror from 1.0.0 to 1.1.1 (#1877)
  * docs: update for v1.39.0 (#1876)
- Fix go version output to show actual release
* Tue May  4 2021 maciek.borzecki@gmail.com
- Update to version 1.39.0:
  * typecheck: display compilation errors as report instead of error (#1861)
  * docs: add cache directory information. (#1871)
  * docs: typo fixes in architecture.mdx (#1870)
  * Set version command output to Stdout (#1869)
  * Bump importas to HEAD (#1864)
  * build(deps): bump github.com/mgechev/revive from 1.0.3 to 1.0.5 (#1866)
  * build(deps): bump github.com/go-critic/go-critic from 0.5.4 to 0.5.5 (#1867)
  * Bump makezero to HEAD (#1865)
  * Bump wrapcheck to v1.0.0 (#1863)
  * fix: linters load mode (#1862)
  * Add versions, improve deprecation system, improve linters page (#1854)
  * Add new presets (#1847)
  * revive: the default configuration is only applied when no dedicated configuration. (#1831)
  * Bump rowserrcheck to HEAD (#1843)
  * Restore fast linters meaning (#1844)
  * build(deps): bump github.com/sirupsen/logrus from 1.8.0 to 1.8.1 (#1845)
  * docs: improve linters page (#1842)
  * nolintlint: allow to fix //nolint lines (#1583)
  * docs: adding missing format options (#1840)
  * dev: remove old TODO and remove assert import alias on require. (#1838)
  * bump ifshort to v1.0.2 (#1837)
  * Bump gofumpt from v0.1.0 to v0.1.1 (#1834)
  * dev: clean configuration and code (#1830)
  * build(deps): bump github.com/securego/gosec/v2 from 2.6.1 to 2.7.0 (#1823)
  * Deprecate 'scopelint' linter (#1819)
  * Bump staticcheck to 2020.2.3 (v0.1.3) (#1829)
  * Improve issue templates chooser. (#1821)
  * Add gomoddirectives linter. (#1817)
  * build(deps): bump github.com/shirou/gopsutil/v3 from 3.21.1 to 3.21.2 (#1822)
  * docs: Update .golangci.example.yml (#1816)
  * bump wastedassign to v0.2.0 (#1815)
  * docs: Update for v1.38.0 (#1827)
  * Update Docs and Assets Github Actions (#1460)
  * build(deps): bump gatsby-source-filesystem in /docs (#1806)
  * build(deps): bump gatsby-plugin-manifest from 2.12.0 to 2.12.1 in /docs (#1807)
  * build(deps): bump gatsby-plugin-offline from 3.10.0 to 3.10.2 in /docs (#1801)
  * build(deps): bump gatsby-transformer-remark in /docs (#1805)
  * build(deps): bump gatsby from 2.32.3 to 2.32.8 in /docs (#1804)
  * build(deps): bump prism-react-renderer from 1.1.1 to 1.2.0 in /docs (#1802)
  * build(deps): bump gatsby-plugin-mdx from 1.10.0 to 1.10.1 in /docs (#1800)
  * Use go v1.14 in go.mod file (#1803)
  * build(deps): bump puppeteer from 7.0.1 to 8.0.0 in /docs (#1796)
  * build(deps): bump gatsby-remark-images from 3.11.0 to 3.11.1 in /docs (#1799)
  * build(deps): bump polished from 4.1.0 to 4.1.1 in /docs (#1797)
  * build(deps): bump golangci/golangci-lint-action from v2.4.0 to v2.5.1 (#1798)
  * build(deps): bump gatsby-plugin-sharp from 2.14.1 to 2.14.3 in /docs (#1795)
  * fix: use same default linter as go vet. (#1793)
  * docs: update url of gocyclo linter (#1794)
  * Update dependencies that dependabot cannot (#1790)
  * Remove outdated CVEs from .nancy-ignore (#1791)
  * Add ForceTypeAssert linter (#1789)
  * Add nilerr linter. (#1788)
  * Integrate ImportAs linter (#1783)
  * Using a version instead of commit id for goconst (#1786)
  * Fix go-header usage (#1785)
  * docs: improve the bug issue template. (#1781)
  * ineffassign: use upstrea  instead of golangci fork (#1780)
  * Use errcheck from main repo instead of golangci-lint fork (#1319)
  * docs: improve gocritic description (#1766)
  * docs: Updated deprecated hyperlink for Sublime Text plugin. (#1775)
  * Support RelatedInformation for analysis Diagnostic (#1773)
  * revive: add rule name in message. (#1772)
  * Deprecate maligned, add govet `fieldalignment` as replacement (#1765)
  * build(deps): bump github.com/sirupsen/logrus from 1.7.0 to 1.8.0 (#1763)
  * build(deps): bump github.com/kulti/thelper from 0.3.1 to 0.4.0 (#1764)
  * build(deps): bump sonatype-nexus-community/nancy-github-action (#1762)
  * Add linter wastedassign (#1651)
  * test: Remove comparison to gometalinter in benchmarks (#1732)
  * add doc for the profiling arguments (#1761)
  * Update staticcheck to v0.1.2 (2020.2.2) (#1756)
  * Bump github.com/Djarvur/go-err113 to HEAD (#1760)
  * test: Bump github.com/shirou/gopsutil to v3.21.1 (#1759)
  * Bump github.com/timakin/bodyclose to HEAD (#1758)
  * bump durationcheck from 0.0.4 to 0.0.6 (#1757)
  * Deprecate `Interfacer` linter (#1755)
  * test: Allow fix tests to run concurrently (#1576)
  * Add stringintconv and ifaceassert to govet (#1360)
  * docs: Add docs on using homebrew tap (#1660)
  * Bump wsl to v3.2.0 (#1750)
  * Exclude PR about doc dependencies from release changelog. (#1752)
  * docs: Update for v1.37.1 (#1751)
* Mon Feb 22 2021 maciek.borzecki@gmail.com
- Update to version 1.37.1:
  * durationcheck: False positive when multiplying with int type struct field (#1744)
  * exhaustivestruct: add missing settings (#1746)
  * revive: fix types and default configuration. (#1747)
  * cyclop: add missing settings (#1743)
  * Update doc for v1.37.0 (#1742)
  * Use upstream gocyclo. (#1739)
  * add 'cyclop' linter (#1738)
  * Add go1.16 support (#1740)
  * build(deps): bump github.com/spf13/cobra from 1.1.1 to 1.1.3 (#1736)
  * build(deps): bump golangci/golangci-lint-action from v2.3.0 to v2.4.0 (#1735)
  * fix: wrong load mode (#1733)
  * feat: add durationcheck linter. (#1734)
  * Add "revive" linter (#1729)
  * fix: new-from-rev for large repository. (#1723)
  * Remove gometalinter comparison (#1731)
  * Add plugin option for Goland (#1720)
  * build(deps): bump actions/cache from v2 to v2.1.4 (#1721)
  * build(deps): bump github.com/kulti/thelper from 0.3.0 to 0.3.1 (#1722)
  * docs(clean): replace `govet` example with `nakedret`. (#1647)
  * fix MIPS release (#1697)
  * bump thelper linter version to v0.3.0 (#1696)
  * build(deps): bump gatsby-transformer-remark in /docs (#1719)
  * build(deps): bump gatsby-transformer-yaml from 2.8.0 to 2.11.0 in /docs (#1718)
  * build(deps): bump react-icons from 4.1.0 to 4.2.0 in /docs (#1717)
  * build(deps): bump gatsby from 2.29.3 to 2.32.3 in /docs (#1716)
  * build(deps): bump gatsby-plugin-google-analytics in /docs (#1715)
  * build(deps): bump gatsby-source-filesystem from 2.8.1 to 2.11.0 in /docs (#1714)
  * build(deps): bump gatsby-transformer-sharp in /docs (#1712)
  * build(deps): bump gatsby-plugin-canonical-urls in /docs (#1713)
  * build(deps): bump gatsby-remark-autolink-headers in /docs (#1711)
  * build(deps): bump gatsby-plugin-catch-links in /docs (#1710)
  * build(deps): bump gatsby-plugin-react-helmet in /docs (#1709)
  * build(deps): bump polished from 4.0.5 to 4.1.0 in /docs (#1708)
  * build(deps): bump puppeteer from 5.5.0 to 7.0.1 in /docs (#1707)
  * build(deps): bump gatsby-plugin-mdx from 1.7.1 to 1.10.0 in /docs (#1706)
  * build(deps): bump gatsby-remark-copy-linked-files in /docs (#1705)
  * build(deps): bump gatsby-plugin-manifest from 2.9.1 to 2.12.0 in /docs (#1704)
  * build(deps): bump gatsby-plugin-sitemap from 2.9.0 to 2.12.0 in /docs (#1703)
  * build(deps): bump gatsby-remark-images from 3.8.1 to 3.11.0 in /docs (#1702)
  * build(deps): bump gatsby-plugin-sharp from 2.11.2 to 2.14.1 in /docs (#1699)
  * build(deps): bump gatsby-remark-responsive-iframe in /docs (#1698)
  * build(deps): bump gatsby-plugin-offline from 3.7.1 to 3.10.0 in /docs (#1701)
  * build(deps): bump gatsby-plugin-netlify from 2.8.0 to 2.11.0 in /docs (#1700)
  * build(deps): bump gatsby-remark-autolink-headers in /docs (#1674)
  * fix(cmd/linters): truncate multiline descriptions (#1663)
  * build(deps): bump gatsby-transformer-sharp from 2.9.0 to 2.11.0 in /docs (#1673)
  * Compile binaries with -trimpath enabled (#1688)
  * prealloc: Use upstream version (#1694)
  * fix: add missing ifshort configuration. (#1672)
  * build(deps): bump github.com/mbilski/exhaustivestruct from 1.1.0 to 1.2.0 (#1680)
  * build(deps): bump github.com/tetafro/godot from 1.4.3 to 1.4.4 (#1679)
  * Expose more config options for forbidigo (#1677)
  * Print error message and exit with non-zero status when ruleguard parse error occurs (#1666)
  * build(deps): bump github.com/ashanbrown/forbidigo from 1.0.0 to 1.1.0 (#1678)
  * Update ifshort to v1.0.1 (#1671)
  * rowserrcheck: fix reports false positive (#1670)
  * Add "exclude" option for godot linter (#1669)
  * Update docs for v1.36.0 (#1668)
* Wed Jan 27 2021 Maciej Borzecki <maciek.borzecki@gmail.com>
- Update to 1.36.0
